/*
 * This file is part of Cadmium.
 * Copyright (C) 2007-2009 Xavier Clerc.
 *
 * Cadmium is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Cadmium is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "fail.h"
#include "mlvalues.h"
#include "prims.h"


/********************* fr.x9c.cadmium.primitives.cadmium *********************/

/* Primitives from Cadmium */

CAMLprim value cadmium_is_available(value unit) {
  return Val_bool(0);
}
PRIM1(cadmium_is_null)
PRIM1(cadmium_get_null)
PRIM2(cadmium_instance_of)
PRIM1(cadmium_object_of_string)
PRIM1(cadmium_java_char_of_char)
PRIM1(cadmium_char_of_java_char)
PRIM2(cadmium_equal)
PRIM2(cadmium_not_equal)
PRIM2(cadmium_print_stack_trace)
PRIM1(cadmium_throw_exception)
PRIM2(cadmium_synchronized)
PRIM1(cadmium_get_frame)
PRIM1(cadmium_get_canvas)
PRIM1(cadmium_get_buffer)
PRIM1(cadmium_get_binding)
PRIM1(cadmium_is_binding_object)


/* Primitives from Objects */

PRIM1(cadmium_object_make)
PRIM1(cadmium_object_clone)
PRIM2(cadmium_object_equals)
PRIM1(cadmium_object_get_class)
PRIM1(cadmium_object_hash_code)
PRIM1(cadmium_object_notify)
PRIM1(cadmium_object_notify_all)
PRIM1(cadmium_object_to_string)
PRIM1(cadmium_object_wait)
PRIM2(cadmium_object_wait_time1)
PRIM3(cadmium_object_wait_time2)


/* Primitives from Classes */

PRIM2(cadmium_class_cast)
PRIM1(cadmium_class_for_name)
PRIM1(cadmium_class_get_canonical_name)
PRIM2(cadmium_class_get_constructor)
PRIM1(cadmium_class_get_constructors)
PRIM2(cadmium_class_get_declared_constructor)
PRIM1(cadmium_class_get_declared_constructors)
PRIM2(cadmium_class_get_field)
PRIM1(cadmium_class_get_fields)
PRIM2(cadmium_class_get_declared_field)
PRIM1(cadmium_class_get_declared_fields)
PRIM3(cadmium_class_get_method)
PRIM1(cadmium_class_get_methods)
PRIM3(cadmium_class_get_declared_method)
PRIM1(cadmium_class_get_declared_methods)
PRIM1(cadmium_class_get_interfaces)
PRIM1(cadmium_class_get_modifiers)
PRIM1(cadmium_class_get_name)
PRIM1(cadmium_class_get_package)
PRIM1(cadmium_class_get_simple_name)
PRIM1(cadmium_class_get_superclass)
PRIM1(cadmium_class_is_array)
PRIM1(cadmium_class_is_interface)
PRIM1(cadmium_class_is_primitive)
PRIM1(cadmium_class_new_instance)
PRIM1(cadmium_class_as_class)


/* Primitives from Constructors */

PRIM1(cadmium_constr_get_declaring_class)
PRIM1(cadmium_constr_get_exception_types)
PRIM1(cadmium_constr_get_modifiers)
PRIM1(cadmium_constr_get_parameter_types)
PRIM2(cadmium_constr_new_instance)
PRIM1(cadmium_constr_as_constr)


/* Primitives from Fields */

PRIM1(cadmium_field_get_declaring_class)
PRIM1(cadmium_field_get_modifiers)
PRIM1(cadmium_field_get_name)
PRIM2(cadmium_field_get)
PRIM2(cadmium_field_get_boolean)
PRIM2(cadmium_field_get_byte)
PRIM2(cadmium_field_get_char)
PRIM2(cadmium_field_get_double)
PRIM2(cadmium_field_get_float)
PRIM2(cadmium_field_get_int)
PRIM2(cadmium_field_get_long)
PRIM2(cadmium_field_get_short)
PRIM3(cadmium_field_set)
PRIM3(cadmium_field_set_boolean)
PRIM3(cadmium_field_set_byte)
PRIM3(cadmium_field_set_char)
PRIM3(cadmium_field_set_double)
PRIM3(cadmium_field_set_float)
PRIM3(cadmium_field_set_int)
PRIM3(cadmium_field_set_long)
PRIM3(cadmium_field_set_short)
PRIM1(cadmium_field_as_field)


/* Primitives from Methods */

PRIM1(cadmium_meth_get_declaring_class)
PRIM1(cadmium_meth_get_exception_types)
PRIM1(cadmium_meth_get_modifiers)
PRIM1(cadmium_meth_get_name)
PRIM1(cadmium_meth_get_parameter_types)
PRIM1(cadmium_meth_get_return_type)
PRIM3(cadmium_meth_invoke)
PRIM1(cadmium_meth_as_meth)


/* Primitives from Arrays */

PRIM2(cadmium_array_new_instance)
PRIM2(cadmium_array_new_instance_dims)
PRIM2(cadmium_array_get_length)
PRIM2(cadmium_array_get)
PRIM2(cadmium_array_get_boolean)
PRIM2(cadmium_array_get_byte)
PRIM2(cadmium_array_get_char)
PRIM2(cadmium_array_get_double)
PRIM2(cadmium_array_get_float)
PRIM2(cadmium_array_get_int)
PRIM2(cadmium_array_get_long)
PRIM2(cadmium_array_get_short)
PRIM3(cadmium_array_set)
PRIM3(cadmium_array_set_boolean)
PRIM3(cadmium_array_set_byte)
PRIM3(cadmium_array_set_char)
PRIM3(cadmium_array_set_double)
PRIM3(cadmium_array_set_float)
PRIM3(cadmium_array_set_int)
PRIM3(cadmium_array_set_long)
PRIM3(cadmium_array_set_short)


/* Primitives from Proxies */

PRIM2(cadmium_register)
PRIM2(cadmium_register_object)
PRIM3(cadmium_register_object_transl)


/* Primitives from Applets */

PRIM2(cadmium_applet_get_parameter)


/* Primitives from Runtime */

PRIM1(cadmium_is_native)
PRIM1(cadmium_get_coderunner)
PRIM1(cadmium_get_context)
PRIM1(cadmium_get_parameters)
PRIM6(cadmium_make_interpreter_native)
PRIMN(cadmium_make_interpreter)
PRIM1(cadmium_interpreter_execute)
PRIM3(cadmium_interpreter_execute_callback)
PRIM1(cadmium_interpreter_get_context)
PRIM1(cadmium_interpreter_get_parameters)


/* Primitives from CreateInterface */

PRIM1(cadmium_create_interface)
PRIM2(cadmium_create_named_interface)



/******************* fr.x9c.cadmium.primitives.cadmiumxml *******************/

/* Primitives from Documents */

PRIM1(cadmiumxml_document_get_document_element)
PRIM1(cadmiumxml_document_get_xml_encoding)
PRIM2(cadmiumxml_document_set_strict_error_checking)
PRIM1(cadmiumxml_document_is_strict_error_checking)
PRIM2(cadmiumxml_document_set_xml_standalone)
PRIM1(cadmiumxml_document_is_xml_standalone)
PRIM2(cadmiumxml_document_set_xml_version)
PRIM1(cadmiumxml_document_get_xml_version)
PRIM1(cadmiumxml_document_normalize_document)
PRIM1(cadmiumxml_document_get_attr_parent)
PRIM1(cadmiumxml_document_get_attr_name)
PRIM1(cadmiumxml_document_get_attr_value)
PRIM2(cadmiumxml_document_set_attr_value)
PRIM1(cadmiumxml_document_get_cdata_parent)
PRIM1(cadmiumxml_document_get_cdata)
PRIM2(cadmiumxml_document_set_cdata)
PRIM1(cadmiumxml_document_get_comment_parent)
PRIM1(cadmiumxml_document_get_comment)
PRIM2(cadmiumxml_document_set_comment)
PRIM1(cadmiumxml_document_get_document_type_parent)
PRIM1(cadmiumxml_document_get_document_type_name)
PRIM1(cadmiumxml_document_get_document_type_public_id)
PRIM1(cadmiumxml_document_get_document_type_system_id)
PRIM1(cadmiumxml_document_get_element_parent)
PRIM2(cadmiumxml_document_get_attribute)
PRIM3(cadmiumxml_document_get_attribute_ns)
PRIM2(cadmiumxml_document_get_attribute_node)
PRIM3(cadmiumxml_document_get_attribute_node_ns)
PRIM2(cadmiumxml_document_get_elements_by_tag_name)
PRIM3(cadmiumxml_document_get_elements_by_tag_name_ns)
PRIM1(cadmiumxml_document_get_tag_name)
PRIM2(cadmiumxml_document_has_attribute)
PRIM3(cadmiumxml_document_has_attribute_ns)
PRIM2(cadmiumxml_document_remove_attribute)
PRIM3(cadmiumxml_document_remove_attribute_ns)
PRIM2(cadmiumxml_document_remove_attribute_node)
PRIM3(cadmiumxml_document_set_attribute)
PRIM4(cadmiumxml_document_set_attribute_ns)
PRIM1(cadmiumxml_document_get_entity_parent)
PRIM1(cadmiumxml_document_get_entity_notation_name)
PRIM1(cadmiumxml_document_get_entity_public_id)
PRIM1(cadmiumxml_document_get_entity_system_id)
PRIM1(cadmiumxml_document_get_notation_parent)
PRIM1(cadmiumxml_document_get_notation_public_id)
PRIM1(cadmiumxml_document_get_notation_system_id)
PRIM1(cadmiumxml_document_get_processing_instruction_parent)
PRIM1(cadmiumxml_document_get_processing_instruction_target)
PRIM1(cadmiumxml_document_get_processing_instruction_data)
PRIM2(cadmiumxml_document_set_processing_instruction_data)
PRIM1(cadmiumxml_document_get_text_parent)
PRIM1(cadmiumxml_document_get_text)
PRIM2(cadmiumxml_document_set_text)
PRIM1(cadmiumxml_document_get_parent)
PRIM1(cadmiumxml_document_get_document)
PRIM2(cadmiumxml_document_append_attr_child)
PRIM3(cadmiumxml_document_append_attr_ns_child)
PRIM2(cadmiumxml_document_append_cdata_child)
PRIM2(cadmiumxml_document_append_comment_child)
PRIM2(cadmiumxml_document_append_element_child)
PRIM3(cadmiumxml_document_append_element_ns_child)
PRIM2(cadmiumxml_document_append_entity_reference_child)
PRIM3(cadmiumxml_document_insert_attr_child_before)
PRIM4(cadmiumxml_document_insert_attr_ns_child_before)
PRIM3(cadmiumxml_document_insert_cdata_child_before)
PRIM3(cadmiumxml_document_insert_comment_child_before)
PRIM3(cadmiumxml_document_insert_element_child_before)
PRIM4(cadmiumxml_document_insert_element_ns_child_before)
PRIM3(cadmiumxml_document_insert_entity_reference_child_before)
PRIM1(cadmiumxml_document_get_child_nodes)
PRIM1(cadmiumxml_document_get_first_child)
PRIM1(cadmiumxml_document_get_last_child)
PRIM1(cadmiumxml_document_get_previous_sibling)
PRIM1(cadmiumxml_document_get_next_sibling)
PRIM2(cadmiumxml_document_remove_child)
PRIM3(cadmiumxml_document_replace_child)
PRIM1(cadmiumxml_documentfactory_make)
PRIM3(cadmiumxml_documentfactory_set_attribute)
PRIM2(cadmiumxml_documentfactory_get_attribute)
PRIM3(cadmiumxml_documentfactory_set_feature)
PRIM2(cadmiumxml_documentfactory_get_feature)
PRIM2(cadmiumxml_documentfactory_set_schema)
PRIM1(cadmiumxml_documentfactory_get_schema)
PRIM2(cadmiumxml_documentfactory_set_coalescing)
PRIM1(cadmiumxml_documentfactory_is_coalescing)
PRIM2(cadmiumxml_documentfactory_set_expand_entity_references)
PRIM1(cadmiumxml_documentfactory_is_expand_entity_references)
PRIM2(cadmiumxml_documentfactory_set_ignoring_comments)
PRIM1(cadmiumxml_documentfactory_is_ignoring_comments)
PRIM2(cadmiumxml_documentfactory_set_ignoring_element_content_whitespace)
PRIM1(cadmiumxml_documentfactory_is_ignoring_element_content_whitespace)
PRIM2(cadmiumxml_documentfactory_set_namespace_aware)
PRIM1(cadmiumxml_documentfactory_is_namespace_aware)
PRIM2(cadmiumxml_documentfactory_set_validating)
PRIM1(cadmiumxml_documentfactory_is_validating)
PRIM2(cadmiumxml_documentfactory_set_xinclude_aware)
PRIM1(cadmiumxml_documentfactory_is_xinclude_aware)
PRIM1(cadmiumxml_documentbuilder_make)
PRIM1(cadmiumxml_documentbuilder_get_schema)
PRIM1(cadmiumxml_documentbuilder_is_namespace_aware)
PRIM1(cadmiumxml_documentbuilder_is_validating)
PRIM1(cadmiumxml_documentbuilder_is_xinclude_aware)
PRIM1(cadmiumxml_documentbuilder_new_document)
PRIM2(cadmiumxml_documentbuilder_parse_file)
PRIM2(cadmiumxml_documentbuilder_parse_channel)
PRIM1(cadmiumxml_documentbuilder_reset)


/* Primitives from SAX */

PRIM1(cadmiumxml_saxfactory_make)
PRIM3(cadmiumxml_saxfactory_set_feature)
PRIM2(cadmiumxml_saxfactory_get_feature)
PRIM2(cadmiumxml_saxfactory_set_schema)
PRIM1(cadmiumxml_saxfactory_get_schema)
PRIM2(cadmiumxml_saxfactory_set_namespace_aware)
PRIM1(cadmiumxml_saxfactory_is_namespace_aware)
PRIM2(cadmiumxml_saxfactory_set_validating)
PRIM1(cadmiumxml_saxfactory_is_validating)
PRIM2(cadmiumxml_saxfactory_set_xinclude_aware)
PRIM1(cadmiumxml_saxfactory_is_xinclude_aware)
PRIM1(cadmiumxml_sax_make)
PRIM3(cadmiumxml_sax_set_property)
PRIM2(cadmiumxml_sax_get_property)
PRIM1(cadmiumxml_sax_get_schema)
PRIM1(cadmiumxml_sax_is_namespace_aware)
PRIM1(cadmiumxml_sax_is_validating)
PRIM1(cadmiumxml_sax_is_xinclude_aware)
PRIM3(cadmiumxml_sax_parse_file)
PRIM3(cadmiumxml_sax_parse_channel)
PRIM1(cadmiumxml_sax_reset)


/* Primitives from Schema */

PRIM1(cadmiumxml_schemafactory_make)
PRIM3(cadmiumxml_schemafactory_set_feature)
PRIM2(cadmiumxml_schemafactory_get_feature)
PRIM3(cadmiumxml_schemafactory_set_property)
PRIM2(cadmiumxml_schemafactory_get_property)
PRIM2(cadmiumxml_schema_from_file)
PRIM2(cadmiumxml_schema_from_url)


/* Primitives from Transformers */

PRIM1(cadmiumxml_transformerfactory_make)
PRIM3(cadmiumxml_transformerfactory_set_attribute)
PRIM2(cadmiumxml_transformerfactory_get_attribute)
PRIM3(cadmiumxml_transformerfactory_set_feature)
PRIM2(cadmiumxml_transformerfactory_get_feature)
PRIM1(cadmiumxml_transformer_make_id)
PRIM2(cadmiumxml_transformer_make_from_file)
PRIM2(cadmiumxml_transformer_make_from_channel)
PRIM1(cadmiumxml_transformer_clear_parameters)
PRIM3(cadmiumxml_transformer_set_parameter)
PRIM2(cadmiumxml_transformer_get_parameter)
PRIM3(cadmiumxml_transformer_set_output_property)
PRIM2(cadmiumxml_transformer_get_output_property)
PRIM3(cadmiumxml_transformer_transform_file_to_file)
PRIM3(cadmiumxml_transformer_transform_file_to_channel)
PRIM3(cadmiumxml_transformer_transform_channel_to_file)
PRIM3(cadmiumxml_transformer_transform_channel_to_channel)
PRIM1(cadmiumxml_transformer_reset)


/* Primitives from Trees */

PRIM1(cadmiumxml_tree_of_document)


/* Primitives from XPath */

PRIM1(cadmiumxml_xpathfactory_make)
PRIM3(cadmiumxml_xpathfactory_set_feature)
PRIM2(cadmiumxml_xpathfactory_get_feature)
PRIM1(cadmiumxml_xpath_make)
PRIM2(cadmiumxml_xpath_compile)
PRIM3(cadmiumxml_xpath_evaluate_file)
PRIM3(cadmiumxml_xpath_evaluate_channel)
PRIM3(cadmiumxml_xpath_evaluate_document)
PRIM2(cadmiumxml_xpath_expr_evaluate_file)
PRIM2(cadmiumxml_xpath_expr_evaluate_channel)
PRIM2(cadmiumxml_xpath_expr_evaluate_document)
PRIM1(cadmiumxml_xpath_reset)



/******************* fr.x9c.cadmium.primitives.cadmiummath *******************/

/* Primitives from Floats */

PRIM1(cadmiummath_float_get_e)
PRIM1(cadmiummath_float_get_pi)
PRIM1(cadmiummath_float_abs)
PRIM1(cadmiummath_float_acos)
PRIM1(cadmiummath_float_asin)
PRIM1(cadmiummath_float_atan)
PRIM2(cadmiummath_float_atan2)
PRIM1(cadmiummath_float_cbrt)
PRIM1(cadmiummath_float_ceil)
PRIM2(cadmiummath_float_copy_sign)
PRIM1(cadmiummath_float_cos)
PRIM1(cadmiummath_float_cosh)
PRIM1(cadmiummath_float_exp)
PRIM1(cadmiummath_float_exp_m1)
PRIM1(cadmiummath_float_floor)
PRIM1(cadmiummath_float_get_exponent)
PRIM2(cadmiummath_float_hypot)
PRIM2(cadmiummath_float_ieee_remainder)
PRIM1(cadmiummath_float_log)
PRIM1(cadmiummath_float_log10)
PRIM1(cadmiummath_float_log1p)
PRIM2(cadmiummath_float_max)
PRIM2(cadmiummath_float_min)
PRIM2(cadmiummath_float_next_after)
PRIM1(cadmiummath_float_next_up)
PRIM2(cadmiummath_float_pow)
PRIM1(cadmiummath_float_random)
PRIM1(cadmiummath_float_rint)
PRIM1(cadmiummath_float_round)
PRIM2(cadmiummath_float_scalb)
PRIM1(cadmiummath_float_signum)
PRIM1(cadmiummath_float_sin)
PRIM1(cadmiummath_float_sinh)
PRIM1(cadmiummath_float_sqrt)
PRIM1(cadmiummath_float_tan)
PRIM1(cadmiummath_float_tanh)
PRIM1(cadmiummath_float_to_degrees)
PRIM1(cadmiummath_float_to_radians)
PRIM1(cadmiummath_float_ulp)


/* Primitives from StrictFloats */

PRIM1(cadmiummath_strictfloat_get_e)
PRIM1(cadmiummath_strictfloat_get_pi)
PRIM1(cadmiummath_strictfloat_abs)
PRIM1(cadmiummath_strictfloat_acos)
PRIM1(cadmiummath_strictfloat_asin)
PRIM1(cadmiummath_strictfloat_atan)
PRIM2(cadmiummath_strictfloat_atan2)
PRIM1(cadmiummath_strictfloat_cbrt)
PRIM1(cadmiummath_strictfloat_ceil)
PRIM2(cadmiummath_strictfloat_copy_sign)
PRIM1(cadmiummath_strictfloat_cos)
PRIM1(cadmiummath_strictfloat_cosh)
PRIM1(cadmiummath_strictfloat_exp)
PRIM1(cadmiummath_strictfloat_exp_m1)
PRIM1(cadmiummath_strictfloat_floor)
PRIM1(cadmiummath_strictfloat_get_exponent)
PRIM2(cadmiummath_strictfloat_hypot)
PRIM2(cadmiummath_strictfloat_ieee_remainder)
PRIM1(cadmiummath_strictfloat_log)
PRIM1(cadmiummath_strictfloat_log10)
PRIM1(cadmiummath_strictfloat_log1p)
PRIM2(cadmiummath_strictfloat_max)
PRIM2(cadmiummath_strictfloat_min)
PRIM2(cadmiummath_strictfloat_next_after)
PRIM1(cadmiummath_strictfloat_next_up)
PRIM2(cadmiummath_strictfloat_pow)
PRIM1(cadmiummath_strictfloat_random)
PRIM1(cadmiummath_strictfloat_rint)
PRIM1(cadmiummath_strictfloat_round)
PRIM2(cadmiummath_strictfloat_scalb)
PRIM1(cadmiummath_strictfloat_signum)
PRIM1(cadmiummath_strictfloat_sin)
PRIM1(cadmiummath_strictfloat_sinh)
PRIM1(cadmiummath_strictfloat_sqrt)
PRIM1(cadmiummath_strictfloat_tan)
PRIM1(cadmiummath_strictfloat_tanh)
PRIM1(cadmiummath_strictfloat_to_degrees)
PRIM1(cadmiummath_strictfloat_to_radians)
PRIM1(cadmiummath_strictfloat_ulp)


/* Primitives from Randoms */

PRIM1(cadmiummath_random_make)
PRIM1(cadmiummath_random_make_of_int64)
PRIM1(cadmiummath_random_next_boolean)
PRIM2(cadmiummath_random_next_bytes)
PRIM1(cadmiummath_random_next_float)
PRIM1(cadmiummath_random_next_gaussian)
PRIM1(cadmiummath_random_next_int)
PRIM2(cadmiummath_random_next_int_n)
PRIM1(cadmiummath_random_next_int32)
PRIM2(cadmiummath_random_next_int32_n)
PRIM1(cadmiummath_random_next_int64)
PRIM2(cadmiummath_random_set_seed)


/* Primitives from BigIntegers */

PRIM1(cadmiummath_biginteger_get_constant)
PRIM1(cadmiummath_biginteger_make_of_bytes)
PRIM2(cadmiummath_biginteger_make_of_signum_bytes)
PRIM3(cadmiummath_biginteger_make_prime_of_random)
PRIM2(cadmiummath_biginteger_make_of_random)
PRIM1(cadmiummath_biginteger_make_of_string)
PRIM2(cadmiummath_biginteger_make_of_string_radix)
PRIM1(cadmiummath_biginteger_make_of_int64)
PRIM1(cadmiummath_biginteger_abs)
PRIM2(cadmiummath_biginteger_add)
PRIM2(cadmiummath_biginteger_and_)
PRIM2(cadmiummath_biginteger_and_not)
PRIM1(cadmiummath_biginteger_bit_count)
PRIM1(cadmiummath_biginteger_bit_length)
PRIM2(cadmiummath_biginteger_clear_bit)
PRIM2(cadmiummath_biginteger_compare_to)
PRIM2(cadmiummath_biginteger_divide)
PRIM2(cadmiummath_biginteger_divide_and_remainder)
PRIM2(cadmiummath_biginteger_equals)
PRIM2(cadmiummath_biginteger_flip_bit)
PRIM1(cadmiummath_biginteger_float_value)
PRIM2(cadmiummath_biginteger_gcd)
PRIM1(cadmiummath_biginteger_get_lowest_set_bit)
PRIM1(cadmiummath_biginteger_hash_code)
PRIM1(cadmiummath_biginteger_int_value)
PRIM1(cadmiummath_biginteger_int32_value)
PRIM1(cadmiummath_biginteger_int64_value)
PRIM2(cadmiummath_biginteger_is_probably_prime)
PRIM2(cadmiummath_biginteger_max)
PRIM2(cadmiummath_biginteger_min)
PRIM2(cadmiummath_biginteger_mod_)
PRIM2(cadmiummath_biginteger_mod_inverse)
PRIM3(cadmiummath_biginteger_mod_pow)
PRIM2(cadmiummath_biginteger_multiply)
PRIM1(cadmiummath_biginteger_negate)
PRIM1(cadmiummath_biginteger_next_probable_prime)
PRIM1(cadmiummath_biginteger_not)
PRIM2(cadmiummath_biginteger_or_)
PRIM2(cadmiummath_biginteger_pow)
PRIM2(cadmiummath_biginteger_remainder)
PRIM2(cadmiummath_biginteger_set_bit)
PRIM2(cadmiummath_biginteger_shift_left)
PRIM2(cadmiummath_biginteger_shift_right)
PRIM1(cadmiummath_biginteger_signum)
PRIM2(cadmiummath_biginteger_subtract)
PRIM2(cadmiummath_biginteger_test_bit)
PRIM1(cadmiummath_biginteger_to_bytes)
PRIM1(cadmiummath_biginteger_to_string)
PRIM2(cadmiummath_biginteger_to_string_radix)
PRIM2(cadmiummath_biginteger_xor)


/* Primitives from BigDecimals */

PRIM1(cadmiummath_bigdecimal_get_constant)
PRIM1(cadmiummath_bigdecimal_make_of_big_integer)
PRIM2(cadmiummath_bigdecimal_make_of_big_integer_ctxt)
PRIM2(cadmiummath_bigdecimal_make_of_big_integer_scale)
PRIM3(cadmiummath_bigdecimal_make_of_big_integer_scale_ctxt)
PRIM1(cadmiummath_bigdecimal_make_of_float)
PRIM2(cadmiummath_bigdecimal_make_of_float_ctxt)
PRIM1(cadmiummath_bigdecimal_make_of_int32)
PRIM2(cadmiummath_bigdecimal_make_of_int32_ctxt)
PRIM1(cadmiummath_bigdecimal_make_of_int64)
PRIM2(cadmiummath_bigdecimal_make_of_int64_ctxt)
PRIM1(cadmiummath_bigdecimal_make_of_string)
PRIM2(cadmiummath_bigdecimal_make_of_string_ctxt)
PRIM1(cadmiummath_bigdecimal_abs)
PRIM2(cadmiummath_bigdecimal_abs_ctxt)
PRIM2(cadmiummath_bigdecimal_add)
PRIM3(cadmiummath_bigdecimal_add_ctxt)
PRIM1(cadmiummath_bigdecimal_byte_value_exact)
PRIM2(cadmiummath_bigdecimal_compare_to)
PRIM2(cadmiummath_bigdecimal_divide)
PRIM4(cadmiummath_bigdecimal_divide_scale_mode)
PRIM3(cadmiummath_bigdecimal_divide_ctxt)
PRIM3(cadmiummath_bigdecimal_divide_mode)
PRIM2(cadmiummath_bigdecimal_divide_and_remainder)
PRIM3(cadmiummath_bigdecimal_divide_and_remainder_ctxt)
PRIM2(cadmiummath_bigdecimal_divide_to_integral_value)
PRIM3(cadmiummath_bigdecimal_divide_to_integral_value_ctxt)
PRIM2(cadmiummath_bigdecimal_equals)
PRIM1(cadmiummath_bigdecimal_float_value)
PRIM1(cadmiummath_bigdecimal_hash_code)
PRIM1(cadmiummath_bigdecimal_int_value)
PRIM1(cadmiummath_bigdecimal_int_value_exact)
PRIM1(cadmiummath_bigdecimal_int32_value)
PRIM1(cadmiummath_bigdecimal_int32_value_exact)
PRIM1(cadmiummath_bigdecimal_int64_value)
PRIM1(cadmiummath_bigdecimal_int64_value_exact)
PRIM2(cadmiummath_bigdecimal_max)
PRIM2(cadmiummath_bigdecimal_min)
PRIM2(cadmiummath_bigdecimal_move_point_left)
PRIM2(cadmiummath_bigdecimal_move_point_right)
PRIM2(cadmiummath_bigdecimal_multiply)
PRIM3(cadmiummath_bigdecimal_multiply_ctxt)
PRIM1(cadmiummath_bigdecimal_negate)
PRIM2(cadmiummath_bigdecimal_negate_ctxt)
PRIM1(cadmiummath_bigdecimal_plus)
PRIM2(cadmiummath_bigdecimal_plus_ctxt)
PRIM2(cadmiummath_bigdecimal_pow)
PRIM3(cadmiummath_bigdecimal_pow_ctxt)
PRIM1(cadmiummath_bigdecimal_precision)
PRIM2(cadmiummath_bigdecimal_remainder)
PRIM3(cadmiummath_bigdecimal_remainder_ctxt)
PRIM2(cadmiummath_bigdecimal_round)
PRIM1(cadmiummath_bigdecimal_scale)
PRIM2(cadmiummath_bigdecimal_scale_by_power_of_ten)
PRIM2(cadmiummath_bigdecimal_set_scale)
PRIM3(cadmiummath_bigdecimal_set_scale_mode)
PRIM1(cadmiummath_bigdecimal_short_value_exact)
PRIM1(cadmiummath_bigdecimal_signum)
PRIM1(cadmiummath_bigdecimal_strip_trailing_zeros)
PRIM2(cadmiummath_bigdecimal_subtract)
PRIM3(cadmiummath_bigdecimal_subtract_ctxt)
PRIM1(cadmiummath_bigdecimal_to_big_integer)
PRIM1(cadmiummath_bigdecimal_to_big_integer_exact)
PRIM1(cadmiummath_bigdecimal_to_engineering_string)
PRIM1(cadmiummath_bigdecimal_to_plain_string)
PRIM1(cadmiummath_bigdecimal_to_string)
PRIM1(cadmiummath_bigdecimal_ulp)
PRIM1(cadmiummath_bigdecimal_unscaled_value)



/******************* fr.x9c.cadmium.primitives.cadmiumjdbc *******************/

/* Primitives from Arrays */

PRIM1(cadmiumjdbc_array_free)
PRIM1(cadmiumjdbc_array_get_array)
PRIM3(cadmiumjdbc_array_get_array_slice)
PRIM1(cadmiumjdbc_array_get_base_type)
PRIM1(cadmiumjdbc_array_get_base_type_name)


/* Primitives from Blobs */

PRIM1(cadmiumjdbc_blob_free)
PRIM1(cadmiumjdbc_blob_get_binary_stream)
PRIM3(cadmiumjdbc_blob_get_binary_stream_pos)
PRIM3(cadmiumjdbc_blob_get_bytes)
PRIM1(cadmiumjdbc_blob_length)
PRIM3(cadmiumjdbc_blob_position_blob)
PRIM3(cadmiumjdbc_blob_position_bytes)
PRIM2(cadmiumjdbc_blob_set_binary_stream)
PRIM3(cadmiumjdbc_blob_set_bytes)
PRIM5(cadmiumjdbc_blob_set_bytes_ofs)
PRIM2(cadmiumjdbc_blob_truncate)


/* Primitives from CallableStatements */

PRIM2(cadmiumjdbc_callablestatement_get_array_idx)
PRIM2(cadmiumjdbc_callablestatement_get_array_name)
PRIM2(cadmiumjdbc_callablestatement_get_big_decimal_idx)
PRIM2(cadmiumjdbc_callablestatement_get_big_decimal_name)
PRIM2(cadmiumjdbc_callablestatement_get_blob_idx)
PRIM2(cadmiumjdbc_callablestatement_get_blob_name)
PRIM2(cadmiumjdbc_callablestatement_get_boolean_idx)
PRIM2(cadmiumjdbc_callablestatement_get_boolean_name)
PRIM2(cadmiumjdbc_callablestatement_get_byte_idx)
PRIM2(cadmiumjdbc_callablestatement_get_byte_name)
PRIM2(cadmiumjdbc_callablestatement_get_bytes_idx)
PRIM2(cadmiumjdbc_callablestatement_get_bytes_name)
PRIM2(cadmiumjdbc_callablestatement_get_clob_idx)
PRIM2(cadmiumjdbc_callablestatement_get_clob_name)
PRIM2(cadmiumjdbc_callablestatement_get_date_idx)
PRIM2(cadmiumjdbc_callablestatement_get_date_name)
PRIM2(cadmiumjdbc_callablestatement_get_double_idx)
PRIM2(cadmiumjdbc_callablestatement_get_double_name)
PRIM2(cadmiumjdbc_callablestatement_get_float_idx)
PRIM2(cadmiumjdbc_callablestatement_get_float_name)
PRIM2(cadmiumjdbc_callablestatement_get_int_idx)
PRIM2(cadmiumjdbc_callablestatement_get_int_name)
PRIM2(cadmiumjdbc_callablestatement_get_long_idx)
PRIM2(cadmiumjdbc_callablestatement_get_long_name)
PRIM2(cadmiumjdbc_callablestatement_get_nclob_idx)
PRIM2(cadmiumjdbc_callablestatement_get_nclob_name)
PRIM2(cadmiumjdbc_callablestatement_get_nstring_idx)
PRIM2(cadmiumjdbc_callablestatement_get_nstring_name)
PRIM2(cadmiumjdbc_callablestatement_get_object_idx)
PRIM2(cadmiumjdbc_callablestatement_get_object_name)
PRIM2(cadmiumjdbc_callablestatement_get_ref_idx)
PRIM2(cadmiumjdbc_callablestatement_get_ref_name)
PRIM2(cadmiumjdbc_callablestatement_get_row_id_idx)
PRIM2(cadmiumjdbc_callablestatement_get_row_id_name)
PRIM2(cadmiumjdbc_callablestatement_get_short_idx)
PRIM2(cadmiumjdbc_callablestatement_get_short_name)
PRIM2(cadmiumjdbc_callablestatement_get_sqlxml_idx)
PRIM2(cadmiumjdbc_callablestatement_get_sqlxml_name)
PRIM2(cadmiumjdbc_callablestatement_get_string_idx)
PRIM2(cadmiumjdbc_callablestatement_get_string_name)
PRIM2(cadmiumjdbc_callablestatement_get_time_idx)
PRIM2(cadmiumjdbc_callablestatement_get_time_name)
PRIM2(cadmiumjdbc_callablestatement_get_timestamp_idx)
PRIM2(cadmiumjdbc_callablestatement_get_timestamp_name)
PRIM2(cadmiumjdbc_callablestatement_get_url_idx)
PRIM2(cadmiumjdbc_callablestatement_get_url_name)
PRIM3(cadmiumjdbc_callablestatement_register_out_parameter_idx)
PRIM4(cadmiumjdbc_callablestatement_register_out_parameter_scale_idx)
PRIM3(cadmiumjdbc_callablestatement_register_out_parameter_name)
PRIM4(cadmiumjdbc_callablestatement_register_out_parameter_scale_name)
PRIM3(cadmiumjdbc_callablestatement_set_ascii_stream_name)
PRIM4(cadmiumjdbc_callablestatement_set_ascii_stream_length_name)
PRIM4(cadmiumjdbc_callablestatement_set_ascii_stream_length64_name)
PRIM3(cadmiumjdbc_callablestatement_set_big_decimal_name)
PRIM3(cadmiumjdbc_callablestatement_set_binary_stream_name)
PRIM4(cadmiumjdbc_callablestatement_set_binary_stream_length_name)
PRIM4(cadmiumjdbc_callablestatement_set_binary_stream_length64_name)
PRIM3(cadmiumjdbc_callablestatement_set_blob_name)
PRIM3(cadmiumjdbc_callablestatement_set_boolean_name)
PRIM3(cadmiumjdbc_callablestatement_set_byte_name)
PRIM3(cadmiumjdbc_callablestatement_set_bytes_name)
PRIM3(cadmiumjdbc_callablestatement_set_clob_name)
PRIM3(cadmiumjdbc_callablestatement_set_date_name)
PRIM3(cadmiumjdbc_callablestatement_set_double_name)
PRIM3(cadmiumjdbc_callablestatement_set_float_name)
PRIM3(cadmiumjdbc_callablestatement_set_int_name)
PRIM3(cadmiumjdbc_callablestatement_set_long_name)
PRIM3(cadmiumjdbc_callablestatement_set_nclob_name)
PRIM3(cadmiumjdbc_callablestatement_set_nstring_name)
PRIM3(cadmiumjdbc_callablestatement_set_object_name)
PRIM4(cadmiumjdbc_callablestatement_set_object_type_name)
PRIM5(cadmiumjdbc_callablestatement_set_object_type_scale_name)
PRIM3(cadmiumjdbc_callablestatement_set_row_id_name)
PRIM3(cadmiumjdbc_callablestatement_set_short_name)
PRIM3(cadmiumjdbc_callablestatement_set_sqlxml_name)
PRIM3(cadmiumjdbc_callablestatement_set_string_name)
PRIM3(cadmiumjdbc_callablestatement_set_time_name)
PRIM3(cadmiumjdbc_callablestatement_set_timestamp_name)
PRIM3(cadmiumjdbc_callablestatement_set_url_name)


/* Primitives from Clobs */

PRIM1(cadmiumjdbc_clob_free)
PRIM1(cadmiumjdbc_clob_get_ascii_stream)
PRIM3(cadmiumjdbc_clob_get_sub_string)
PRIM1(cadmiumjdbc_clob_length)
PRIM3(cadmiumjdbc_clob_position_clob)
PRIM3(cadmiumjdbc_clob_position_string)
PRIM2(cadmiumjdbc_clob_set_ascii_stream)
PRIM3(cadmiumjdbc_clob_set_string)
PRIM5(cadmiumjdbc_clob_set_string_ofs)
PRIM2(cadmiumjdbc_clob_truncate)


/* Primitives from Connections */

PRIM1(cadmiumjdbc_connection_clear_warnings)
PRIM1(cadmiumjdbc_connection_close)
PRIM1(cadmiumjdbc_connection_commit)
PRIM3(cadmiumjdbc_connection_create_array_of)
PRIM1(cadmiumjdbc_connection_create_blob)
PRIM1(cadmiumjdbc_connection_create_clob)
PRIM1(cadmiumjdbc_connection_create_nclob)
PRIM1(cadmiumjdbc_connection_create_sqlxml)
PRIM1(cadmiumjdbc_connection_create_statement)
PRIM3(cadmiumjdbc_connection_create_statement_type_conc)
PRIM4(cadmiumjdbc_connection_create_statement_type_conc_hold)
PRIM3(cadmiumjdbc_connection_create_struct)
PRIM1(cadmiumjdbc_connection_get_auto_commit)
PRIM1(cadmiumjdbc_connection_get_catalog)
PRIM1(cadmiumjdbc_connection_get_client_infos)
PRIM2(cadmiumjdbc_connection_get_client_info)
PRIM1(cadmiumjdbc_connection_get_holdability)
PRIM1(cadmiumjdbc_connection_get_meta_data)
PRIM1(cadmiumjdbc_connection_get_transaction_isolation)
PRIM1(cadmiumjdbc_connection_get_warnings)
PRIM1(cadmiumjdbc_connection_is_closed)
PRIM1(cadmiumjdbc_connection_is_read_only)
PRIM2(cadmiumjdbc_connection_is_valid)
PRIM2(cadmiumjdbc_connection_native_sql)
PRIM2(cadmiumjdbc_connection_prepare_call)
PRIM4(cadmiumjdbc_connection_prepare_call_type_conc)
PRIM5(cadmiumjdbc_connection_prepare_call_type_conc_hold)
PRIM2(cadmiumjdbc_connection_prepare_statement)
PRIM3(cadmiumjdbc_connection_prepare_statement_autogen_keys)
PRIM3(cadmiumjdbc_connection_prepare_statement_indexes)
PRIM4(cadmiumjdbc_connection_prepare_statement_type_conc)
PRIM5(cadmiumjdbc_connection_prepare_statement_type_conc_hold)
PRIM3(cadmiumjdbc_connection_prepare_statement_names)
PRIM2(cadmiumjdbc_connection_release_savepoint)
PRIM1(cadmiumjdbc_connection_rollback)
PRIM2(cadmiumjdbc_connection_rollback_to)
PRIM2(cadmiumjdbc_connection_set_auto_commit)
PRIM2(cadmiumjdbc_connection_set_catalog)
PRIM2(cadmiumjdbc_connection_set_client_infos)
PRIM3(cadmiumjdbc_connection_set_client_info)
PRIM2(cadmiumjdbc_connection_set_holdability)
PRIM2(cadmiumjdbc_connection_set_read_only)
PRIM1(cadmiumjdbc_connection_set_savepoint)
PRIM2(cadmiumjdbc_connection_set_savepoint_with_name)
PRIM2(cadmiumjdbc_connection_set_transaction_isolation)


/* Primitives from DatabaseMetadatas */

PRIM1(cadmiumjdbc_databasemetadata_all_procedures_are_callable)
PRIM1(cadmiumjdbc_databasemetadata_all_tables_are_selectable)
PRIM1(cadmiumjdbc_databasemetadata_auto_commit_failure_closes_all_result_sets)
PRIM1(cadmiumjdbc_databasemetadata_data_definition_causes_transaction_commit)
PRIM1(cadmiumjdbc_databasemetadata_data_definition_ignored_in_transactions)
PRIM2(cadmiumjdbc_databasemetadata_deletes_are_detected)
PRIM1(cadmiumjdbc_databasemetadata_does_max_row_size_include_blobs)
PRIM5(cadmiumjdbc_databasemetadata_get_attributes)
PRIMN(cadmiumjdbc_databasemetadata_get_best_row_identifier)
PRIM6(cadmiumjdbc_databasemetadata_get_best_row_identifier_native)
PRIM1(cadmiumjdbc_databasemetadata_get_catalogs)
PRIM1(cadmiumjdbc_databasemetadata_get_catalog_separator)
PRIM1(cadmiumjdbc_databasemetadata_get_catalog_term)
PRIM1(cadmiumjdbc_databasemetadata_get_client_info_properties)
PRIM5(cadmiumjdbc_databasemetadata_get_column_privileges)
PRIM5(cadmiumjdbc_databasemetadata_get_columns)
PRIMN(cadmiumjdbc_databasemetadata_get_cross_reference)
PRIM7(cadmiumjdbc_databasemetadata_get_cross_reference_native)
PRIM1(cadmiumjdbc_databasemetadata_get_database_major_version)
PRIM1(cadmiumjdbc_databasemetadata_get_database_minor_version)
PRIM1(cadmiumjdbc_databasemetadata_get_database_product_name)
PRIM1(cadmiumjdbc_databasemetadata_get_database_product_version)
PRIM1(cadmiumjdbc_databasemetadata_get_default_transaction_isolation)
PRIM1(cadmiumjdbc_databasemetadata_get_driver_major_version)
PRIM1(cadmiumjdbc_databasemetadata_get_driver_minor_version)
PRIM1(cadmiumjdbc_databasemetadata_get_driver_name)
PRIM1(cadmiumjdbc_databasemetadata_get_driver_version)
PRIM4(cadmiumjdbc_databasemetadata_get_exported_keys)
PRIM1(cadmiumjdbc_databasemetadata_get_extra_name_characters)
PRIM5(cadmiumjdbc_databasemetadata_get_function_columns)
PRIM4(cadmiumjdbc_databasemetadata_get_functions)
PRIM1(cadmiumjdbc_databasemetadata_get_identifier_quote_string)
PRIM4(cadmiumjdbc_databasemetadata_get_imported_keys)
PRIMN(cadmiumjdbc_databasemetadata_get_index_info)
PRIM6(cadmiumjdbc_databasemetadata_get_index_info_native)
PRIM1(cadmiumjdbc_databasemetadata_get_jdbc_major_version)
PRIM1(cadmiumjdbc_databasemetadata_get_jdbc_minor_version)
PRIM1(cadmiumjdbc_databasemetadata_get_max_binary_literal_length)
PRIM1(cadmiumjdbc_databasemetadata_get_max_catalog_name_length)
PRIM1(cadmiumjdbc_databasemetadata_get_max_char_literal_length)
PRIM1(cadmiumjdbc_databasemetadata_get_max_column_name_length)
PRIM1(cadmiumjdbc_databasemetadata_get_max_columns_in_group_by)
PRIM1(cadmiumjdbc_databasemetadata_get_max_columns_in_index)
PRIM1(cadmiumjdbc_databasemetadata_get_max_columns_in_order_by)
PRIM1(cadmiumjdbc_databasemetadata_get_max_columns_in_select)
PRIM1(cadmiumjdbc_databasemetadata_get_max_columns_in_table)
PRIM1(cadmiumjdbc_databasemetadata_get_max_connections)
PRIM1(cadmiumjdbc_databasemetadata_get_max_cursor_name_length)
PRIM1(cadmiumjdbc_databasemetadata_get_max_index_length)
PRIM1(cadmiumjdbc_databasemetadata_get_max_procedure_name_length)
PRIM1(cadmiumjdbc_databasemetadata_get_max_row_size)
PRIM1(cadmiumjdbc_databasemetadata_get_max_schema_name_length)
PRIM1(cadmiumjdbc_databasemetadata_get_max_statement_length)
PRIM1(cadmiumjdbc_databasemetadata_get_max_statements)
PRIM1(cadmiumjdbc_databasemetadata_get_max_table_name_length)
PRIM1(cadmiumjdbc_databasemetadata_get_max_tables_in_select)
PRIM1(cadmiumjdbc_databasemetadata_get_max_user_name_length)
PRIM1(cadmiumjdbc_databasemetadata_get_numeric_functions)
PRIM4(cadmiumjdbc_databasemetadata_get_primary_keys)
PRIM5(cadmiumjdbc_databasemetadata_get_procedure_columns)
PRIM4(cadmiumjdbc_databasemetadata_get_procedures)
PRIM1(cadmiumjdbc_databasemetadata_get_procedure_term)
PRIM1(cadmiumjdbc_databasemetadata_get_result_set_holdability)
PRIM1(cadmiumjdbc_databasemetadata_get_row_id_lifetime)
PRIM1(cadmiumjdbc_databasemetadata_get_schemas)
PRIM3(cadmiumjdbc_databasemetadata_get_schemas_params)
PRIM1(cadmiumjdbc_databasemetadata_get_schema_term)
PRIM1(cadmiumjdbc_databasemetadata_get_search_string_escape)
PRIM1(cadmiumjdbc_databasemetadata_get_sql_keywords)
PRIM1(cadmiumjdbc_databasemetadata_get_sql_state_type)
PRIM1(cadmiumjdbc_databasemetadata_get_string_functions)
PRIM4(cadmiumjdbc_databasemetadata_get_super_tables)
PRIM4(cadmiumjdbc_databasemetadata_get_super_types)
PRIM1(cadmiumjdbc_databasemetadata_get_system_functions)
PRIM4(cadmiumjdbc_databasemetadata_get_table_privileges)
PRIM5(cadmiumjdbc_databasemetadata_get_tables)
PRIM1(cadmiumjdbc_databasemetadata_get_table_types)
PRIM1(cadmiumjdbc_databasemetadata_get_time_date_functions)
PRIM1(cadmiumjdbc_databasemetadata_get_type_info)
PRIM5(cadmiumjdbc_databasemetadata_get_udts)
PRIM1(cadmiumjdbc_databasemetadata_get_url)
PRIM1(cadmiumjdbc_databasemetadata_get_user_name)
PRIM4(cadmiumjdbc_databasemetadata_get_version_columns)
PRIM2(cadmiumjdbc_databasemetadata_inserts_are_detected)
PRIM1(cadmiumjdbc_databasemetadata_is_catalog_at_start)
PRIM1(cadmiumjdbc_databasemetadata_is_read_only)
PRIM1(cadmiumjdbc_databasemetadata_locators_update_copy)
PRIM1(cadmiumjdbc_databasemetadata_null_plus_non_null_is_null)
PRIM1(cadmiumjdbc_databasemetadata_nulls_are_sorted_at_end)
PRIM1(cadmiumjdbc_databasemetadata_nulls_are_sorted_at_start)
PRIM1(cadmiumjdbc_databasemetadata_nulls_are_sorted_high)
PRIM1(cadmiumjdbc_databasemetadata_nulls_are_sorted_low)
PRIM2(cadmiumjdbc_databasemetadata_others_deletes_are_visible)
PRIM2(cadmiumjdbc_databasemetadata_others_inserts_are_visible)
PRIM2(cadmiumjdbc_databasemetadata_others_updates_are_visible)
PRIM2(cadmiumjdbc_databasemetadata_own_deletes_are_visible)
PRIM2(cadmiumjdbc_databasemetadata_own_inserts_are_visible)
PRIM2(cadmiumjdbc_databasemetadata_own_updates_are_visible)
PRIM1(cadmiumjdbc_databasemetadata_stores_lower_case_identifiers)
PRIM1(cadmiumjdbc_databasemetadata_stores_lower_case_quoted_identifiers)
PRIM1(cadmiumjdbc_databasemetadata_stores_mixed_case_identifiers)
PRIM1(cadmiumjdbc_databasemetadata_stores_mixed_case_quoted_identifiers)
PRIM1(cadmiumjdbc_databasemetadata_stores_upper_case_identifiers)
PRIM1(cadmiumjdbc_databasemetadata_stores_upper_case_quoted_identifiers)
PRIM1(cadmiumjdbc_databasemetadata_supports_alter_table_with_add_column)
PRIM1(cadmiumjdbc_databasemetadata_supports_alter_table_with_drop_column)
PRIM1(cadmiumjdbc_databasemetadata_supports_ansi92_entry_level_sql)
PRIM1(cadmiumjdbc_databasemetadata_supports_ansi92_full_sql)
PRIM1(cadmiumjdbc_databasemetadata_supports_ansi92_intermediate_sql)
PRIM1(cadmiumjdbc_databasemetadata_supports_batch_updates)
PRIM1(cadmiumjdbc_databasemetadata_supports_catalogs_in_data_manipulation)
PRIM1(cadmiumjdbc_databasemetadata_supports_catalogs_in_index_definitions)
PRIM1(cadmiumjdbc_databasemetadata_supports_catalogs_in_privilege_definitions)
PRIM1(cadmiumjdbc_databasemetadata_supports_catalogs_in_procedure_calls)
PRIM1(cadmiumjdbc_databasemetadata_supports_catalogs_in_table_definitions)
PRIM1(cadmiumjdbc_databasemetadata_supports_column_aliasing)
PRIM1(cadmiumjdbc_databasemetadata_supports_convert)
PRIM3(cadmiumjdbc_databasemetadata_supports_convert_types)
PRIM1(cadmiumjdbc_databasemetadata_supports_core_sql_grammar)
PRIM1(cadmiumjdbc_databasemetadata_supports_correlated_subqueries)
PRIM1(cadmiumjdbc_databasemetadata_supports_data_definition_and_data_manipulation_transactions)
PRIM1(cadmiumjdbc_databasemetadata_supports_data_manipulation_transactions_only)
PRIM1(cadmiumjdbc_databasemetadata_supports_different_table_correlation_names)
PRIM1(cadmiumjdbc_databasemetadata_supports_expressions_in_order_by)
PRIM1(cadmiumjdbc_databasemetadata_supports_extended_sql_grammar)
PRIM1(cadmiumjdbc_databasemetadata_supports_full_outer_joins)
PRIM1(cadmiumjdbc_databasemetadata_supports_get_generated_keys)
PRIM1(cadmiumjdbc_databasemetadata_supports_group_by)
PRIM1(cadmiumjdbc_databasemetadata_supports_group_by_beyond_select)
PRIM1(cadmiumjdbc_databasemetadata_supports_group_by_unrelated)
PRIM1(cadmiumjdbc_databasemetadata_supports_integrity_enhancement_facility)
PRIM1(cadmiumjdbc_databasemetadata_supports_like_escape_clause)
PRIM1(cadmiumjdbc_databasemetadata_supports_limited_outer_joins)
PRIM1(cadmiumjdbc_databasemetadata_supports_minimum_sql_grammar)
PRIM1(cadmiumjdbc_databasemetadata_supports_mixed_case_identifiers)
PRIM1(cadmiumjdbc_databasemetadata_supports_mixed_case_quoted_identifiers)
PRIM1(cadmiumjdbc_databasemetadata_supports_multiple_open_results)
PRIM1(cadmiumjdbc_databasemetadata_supports_multiple_result_sets)
PRIM1(cadmiumjdbc_databasemetadata_supports_multiple_transactions)
PRIM1(cadmiumjdbc_databasemetadata_supports_named_parameters)
PRIM1(cadmiumjdbc_databasemetadata_supports_non_nullable_columns)
PRIM1(cadmiumjdbc_databasemetadata_supports_open_cursors_across_commit)
PRIM1(cadmiumjdbc_databasemetadata_supports_open_cursors_across_rollback)
PRIM1(cadmiumjdbc_databasemetadata_supports_open_statements_across_commit)
PRIM1(cadmiumjdbc_databasemetadata_supports_open_statements_across_rollback)
PRIM1(cadmiumjdbc_databasemetadata_supports_order_by_unrelated)
PRIM1(cadmiumjdbc_databasemetadata_supports_outer_joins)
PRIM1(cadmiumjdbc_databasemetadata_supports_positioned_delete)
PRIM1(cadmiumjdbc_databasemetadata_supports_positioned_update)
PRIM3(cadmiumjdbc_databasemetadata_supports_result_set_concurrency)
PRIM2(cadmiumjdbc_databasemetadata_supports_result_set_holdability)
PRIM2(cadmiumjdbc_databasemetadata_supports_result_set_type)
PRIM1(cadmiumjdbc_databasemetadata_supports_savepoints)
PRIM1(cadmiumjdbc_databasemetadata_supports_schemas_in_data_manipulation)
PRIM1(cadmiumjdbc_databasemetadata_supports_schemas_in_index_definitions)
PRIM1(cadmiumjdbc_databasemetadata_supports_schemas_in_privilege_definitions)
PRIM1(cadmiumjdbc_databasemetadata_supports_schemas_in_procedure_calls)
PRIM1(cadmiumjdbc_databasemetadata_supports_schemas_in_table_definitions)
PRIM1(cadmiumjdbc_databasemetadata_supports_select_for_update)
PRIM1(cadmiumjdbc_databasemetadata_supports_statement_pooling)
PRIM1(cadmiumjdbc_databasemetadata_supports_stored_functions_using_call_syntax)
PRIM1(cadmiumjdbc_databasemetadata_supports_stored_procedures)
PRIM1(cadmiumjdbc_databasemetadata_supports_subqueries_in_comparisons)
PRIM1(cadmiumjdbc_databasemetadata_supports_subqueries_in_exists)
PRIM1(cadmiumjdbc_databasemetadata_supports_subqueries_in_ins)
PRIM1(cadmiumjdbc_databasemetadata_supports_subqueries_in_quantifieds)
PRIM1(cadmiumjdbc_databasemetadata_supports_table_correlation_names)
PRIM2(cadmiumjdbc_databasemetadata_supports_transaction_isolation_level)
PRIM1(cadmiumjdbc_databasemetadata_supports_transactions)
PRIM1(cadmiumjdbc_databasemetadata_supports_union)
PRIM1(cadmiumjdbc_databasemetadata_supports_union_all)
PRIM2(cadmiumjdbc_databasemetadata_updates_are_detected)
PRIM1(cadmiumjdbc_databasemetadata_uses_local_file_per_table)
PRIM1(cadmiumjdbc_databasemetadata_uses_local_files)


/* Primitives from DateBase */

PRIM2(cadmiumjdbc_datebase_after)
PRIM2(cadmiumjdbc_datebase_before)
PRIM2(cadmiumjdbc_datebase_compare_to)
PRIM2(cadmiumjdbc_datebase_equals)
PRIM1(cadmiumjdbc_datebase_get_day_of_month)
PRIM1(cadmiumjdbc_datebase_get_day_of_week)
PRIM1(cadmiumjdbc_datebase_get_day_of_week_in_month)
PRIM1(cadmiumjdbc_datebase_get_day_of_year)
PRIM1(cadmiumjdbc_datebase_get_hour_of_day)
PRIM1(cadmiumjdbc_datebase_get_millisecond)
PRIM1(cadmiumjdbc_datebase_get_minute)
PRIM1(cadmiumjdbc_datebase_get_month)
PRIM1(cadmiumjdbc_datebase_get_second)
PRIM1(cadmiumjdbc_datebase_get_week_of_month)
PRIM1(cadmiumjdbc_datebase_get_week_of_year)
PRIM1(cadmiumjdbc_datebase_get_year)
PRIM2(cadmiumjdbc_datebase_set_day_of_month)
PRIM2(cadmiumjdbc_datebase_set_day_of_week)
PRIM2(cadmiumjdbc_datebase_set_day_of_week_in_month)
PRIM2(cadmiumjdbc_datebase_set_day_of_year)
PRIM2(cadmiumjdbc_datebase_set_hour_of_day)
PRIM2(cadmiumjdbc_datebase_set_millisecond)
PRIM2(cadmiumjdbc_datebase_set_minute)
PRIM2(cadmiumjdbc_datebase_set_month)
PRIM2(cadmiumjdbc_datebase_set_second)
PRIM2(cadmiumjdbc_datebase_set_week_of_month)
PRIM2(cadmiumjdbc_datebase_set_week_of_year)
PRIM2(cadmiumjdbc_datebase_set_year)


/* Primitives from Dates */

PRIM1(cadmiumjdbc_date_make)
PRIM1(cadmiumjdbc_date_make_of_int64)
PRIM1(cadmiumjdbc_date_make_of_string)
PRIM1(cadmiumjdbc_date_get_time)
PRIM2(cadmiumjdbc_date_set_time)
PRIM1(cadmiumjdbc_date_to_string)


/* Primitives from DriverManagers */

PRIM1(cadmiumjdbc_drivermanager_deregister_driver)
PRIM1(cadmiumjdbc_drivermanager_get_connection)
PRIM2(cadmiumjdbc_drivermanager_get_connection_with_properties)
PRIM3(cadmiumjdbc_drivermanager_get_connection_with_user_passwd)
PRIM1(cadmiumjdbc_drivermanager_get_driver)
PRIM1(cadmiumjdbc_drivermanager_get_drivers)
PRIM1(cadmiumjdbc_drivermanager_get_login_timeout)
PRIM1(cadmiumjdbc_drivermanager_print_log)
PRIM1(cadmiumjdbc_drivermanager_register_driver)
PRIM1(cadmiumjdbc_drivermanager_set_login_timeout)


/* Primitives from Drivers */

PRIM2(cadmiumjdbc_driver_accepts_url)
PRIM3(cadmiumjdbc_driver_connect)
PRIM1(cadmiumjdbc_driver_get_major_version)
PRIM1(cadmiumjdbc_driver_get_minor_version)
PRIM3(cadmiumjdbc_driver_get_property_info)
PRIM1(cadmiumjdbc_driver_is_jdbc_compliant)


/* Primitives from ParameterMetadatas */

PRIM2(cadmiumjdbc_parametermetadata_get_parameter_class_name)
PRIM1(cadmiumjdbc_parametermetadata_get_parameter_count)
PRIM2(cadmiumjdbc_parametermetadata_get_parameter_mode)
PRIM2(cadmiumjdbc_parametermetadata_get_parameter_type)
PRIM2(cadmiumjdbc_parametermetadata_get_parameter_type_name)
PRIM2(cadmiumjdbc_parametermetadata_get_precision)
PRIM2(cadmiumjdbc_parametermetadata_get_scale)
PRIM2(cadmiumjdbc_parametermetadata_is_nullable)
PRIM2(cadmiumjdbc_parametermetadata_is_signed)


/* Primitives from PreparedStatements */

PRIM1(cadmiumjdbc_preparedstatement_add_batch)
PRIM1(cadmiumjdbc_preparedstatement_clear_parameters)
PRIM1(cadmiumjdbc_preparedstatement_execute)
PRIM1(cadmiumjdbc_preparedstatement_execute_query)
PRIM1(cadmiumjdbc_preparedstatement_execute_update)
PRIM1(cadmiumjdbc_preparedstatement_get_meta_data)
PRIM1(cadmiumjdbc_preparedstatement_get_parameter_meta_data)
PRIM3(cadmiumjdbc_preparedstatement_set_array_idx)
PRIM3(cadmiumjdbc_preparedstatement_set_ascii_stream_idx)
PRIM4(cadmiumjdbc_preparedstatement_set_ascii_stream_length_idx)
PRIM4(cadmiumjdbc_preparedstatement_set_ascii_stream_length64_idx)
PRIM3(cadmiumjdbc_preparedstatement_set_big_decimal_idx)
PRIM3(cadmiumjdbc_preparedstatement_set_binary_stream_idx)
PRIM4(cadmiumjdbc_preparedstatement_set_binary_stream_length_idx)
PRIM4(cadmiumjdbc_preparedstatement_set_binary_stream_length64_idx)
PRIM3(cadmiumjdbc_preparedstatement_set_blob_idx)
PRIM3(cadmiumjdbc_preparedstatement_set_boolean_idx)
PRIM3(cadmiumjdbc_preparedstatement_set_byte_idx)
PRIM3(cadmiumjdbc_preparedstatement_set_bytes_idx)
PRIM3(cadmiumjdbc_preparedstatement_set_clob_idx)
PRIM3(cadmiumjdbc_preparedstatement_set_date_idx)
PRIM3(cadmiumjdbc_preparedstatement_set_double_idx)
PRIM3(cadmiumjdbc_preparedstatement_set_float_idx)
PRIM3(cadmiumjdbc_preparedstatement_set_int_idx)
PRIM3(cadmiumjdbc_preparedstatement_set_long_idx)
PRIM3(cadmiumjdbc_preparedstatement_set_nclob_idx)
PRIM3(cadmiumjdbc_preparedstatement_set_nstring_idx)
PRIM3(cadmiumjdbc_preparedstatement_set_object_idx)
PRIM4(cadmiumjdbc_preparedstatement_set_object_type_idx)
PRIM5(cadmiumjdbc_preparedstatement_set_object_type_scale_idx)
PRIM3(cadmiumjdbc_preparedstatement_set_ref_idx)
PRIM3(cadmiumjdbc_preparedstatement_set_row_id_idx)
PRIM3(cadmiumjdbc_preparedstatement_set_short_idx)
PRIM3(cadmiumjdbc_preparedstatement_set_sqlxml_idx)
PRIM3(cadmiumjdbc_preparedstatement_set_string_idx)
PRIM3(cadmiumjdbc_preparedstatement_set_time_idx)
PRIM3(cadmiumjdbc_preparedstatement_set_timestamp_idx)
PRIM3(cadmiumjdbc_preparedstatement_set_url_idx)


/* Primitives from Refs */

PRIM1(cadmiumjdbc_ref_get_base_type_name)
PRIM1(cadmiumjdbc_ref_get_object)
PRIM2(cadmiumjdbc_ref_set_object)


/* Primitives from ResultSetMetadatas */

PRIM2(cadmiumjdbc_resultsetmetadata_get_catalog_name)
PRIM2(cadmiumjdbc_resultsetmetadata_get_column_class_name)
PRIM1(cadmiumjdbc_resultsetmetadata_get_column_count)
PRIM2(cadmiumjdbc_resultsetmetadata_get_column_display_size)
PRIM2(cadmiumjdbc_resultsetmetadata_get_column_label)
PRIM2(cadmiumjdbc_resultsetmetadata_get_column_name)
PRIM2(cadmiumjdbc_resultsetmetadata_get_column_type)
PRIM2(cadmiumjdbc_resultsetmetadata_get_column_type_name)
PRIM2(cadmiumjdbc_resultsetmetadata_get_precision)
PRIM2(cadmiumjdbc_resultsetmetadata_get_scale)
PRIM2(cadmiumjdbc_resultsetmetadata_get_schema_name)
PRIM2(cadmiumjdbc_resultsetmetadata_get_table_name)
PRIM2(cadmiumjdbc_resultsetmetadata_is_auto_increment)
PRIM2(cadmiumjdbc_resultsetmetadata_is_case_sensitive)
PRIM2(cadmiumjdbc_resultsetmetadata_is_currency)
PRIM2(cadmiumjdbc_resultsetmetadata_is_definitely_writable)
PRIM2(cadmiumjdbc_resultsetmetadata_is_nullable)
PRIM2(cadmiumjdbc_resultsetmetadata_is_read_only)
PRIM2(cadmiumjdbc_resultsetmetadata_is_searchable)
PRIM2(cadmiumjdbc_resultsetmetadata_is_signed)
PRIM2(cadmiumjdbc_resultsetmetadata_is_writable)


/* Primitives from ResultSets */

PRIM2(cadmiumjdbc_resultset_absolute)
PRIM1(cadmiumjdbc_resultset_after_last)
PRIM1(cadmiumjdbc_resultset_before_first)
PRIM1(cadmiumjdbc_resultset_cancel_row_updates)
PRIM1(cadmiumjdbc_resultset_clear_warnings)
PRIM1(cadmiumjdbc_resultset_close)
PRIM1(cadmiumjdbc_resultset_delete_row)
PRIM2(cadmiumjdbc_resultset_find_column)
PRIM1(cadmiumjdbc_resultset_first)
PRIM2(cadmiumjdbc_resultset_get_array_idx)
PRIM2(cadmiumjdbc_resultset_get_array_name)
PRIM2(cadmiumjdbc_resultset_get_ascii_stream_idx)
PRIM2(cadmiumjdbc_resultset_get_ascii_stream_name)
PRIM2(cadmiumjdbc_resultset_get_big_decimal_idx)
PRIM2(cadmiumjdbc_resultset_get_big_decimal_name)
PRIM2(cadmiumjdbc_resultset_get_binary_stream_idx)
PRIM2(cadmiumjdbc_resultset_get_binary_stream_name)
PRIM2(cadmiumjdbc_resultset_get_blob_idx)
PRIM2(cadmiumjdbc_resultset_get_blob_name)
PRIM2(cadmiumjdbc_resultset_get_boolean_idx)
PRIM2(cadmiumjdbc_resultset_get_boolean_name)
PRIM2(cadmiumjdbc_resultset_get_byte_idx)
PRIM2(cadmiumjdbc_resultset_get_byte_name)
PRIM2(cadmiumjdbc_resultset_get_bytes_idx)
PRIM2(cadmiumjdbc_resultset_get_bytes_name)
PRIM2(cadmiumjdbc_resultset_get_clob_idx)
PRIM2(cadmiumjdbc_resultset_get_clob_name)
PRIM1(cadmiumjdbc_resultset_get_concurrency)
PRIM1(cadmiumjdbc_resultset_get_cursor_name)
PRIM2(cadmiumjdbc_resultset_get_date_idx)
PRIM2(cadmiumjdbc_resultset_get_date_name)
PRIM2(cadmiumjdbc_resultset_get_double_idx)
PRIM2(cadmiumjdbc_resultset_get_double_name)
PRIM1(cadmiumjdbc_resultset_get_fetch_direction)
PRIM1(cadmiumjdbc_resultset_get_fetch_size)
PRIM2(cadmiumjdbc_resultset_get_float_idx)
PRIM2(cadmiumjdbc_resultset_get_float_name)
PRIM1(cadmiumjdbc_resultset_get_holdability)
PRIM2(cadmiumjdbc_resultset_get_int_idx)
PRIM2(cadmiumjdbc_resultset_get_int_name)
PRIM2(cadmiumjdbc_resultset_get_long_idx)
PRIM2(cadmiumjdbc_resultset_get_long_name)
PRIM1(cadmiumjdbc_resultset_get_meta_data)
PRIM2(cadmiumjdbc_resultset_get_nclob_idx)
PRIM2(cadmiumjdbc_resultset_get_nclob_name)
PRIM2(cadmiumjdbc_resultset_get_nstring_idx)
PRIM2(cadmiumjdbc_resultset_get_nstring_name)
PRIM2(cadmiumjdbc_resultset_get_object_idx)
PRIM2(cadmiumjdbc_resultset_get_object_name)
PRIM2(cadmiumjdbc_resultset_get_ref_idx)
PRIM2(cadmiumjdbc_resultset_get_ref_name)
PRIM1(cadmiumjdbc_resultset_get_row)
PRIM2(cadmiumjdbc_resultset_get_row_id_idx)
PRIM2(cadmiumjdbc_resultset_get_row_id_name)
PRIM2(cadmiumjdbc_resultset_get_short_idx)
PRIM2(cadmiumjdbc_resultset_get_short_name)
PRIM2(cadmiumjdbc_resultset_get_sqlxml_idx)
PRIM2(cadmiumjdbc_resultset_get_sqlxml_name)
PRIM2(cadmiumjdbc_resultset_get_string_idx)
PRIM2(cadmiumjdbc_resultset_get_string_name)
PRIM2(cadmiumjdbc_resultset_get_time_idx)
PRIM2(cadmiumjdbc_resultset_get_time_name)
PRIM2(cadmiumjdbc_resultset_get_timestamp_idx)
PRIM2(cadmiumjdbc_resultset_get_timestamp_name)
PRIM1(cadmiumjdbc_resultset_get_type)
PRIM2(cadmiumjdbc_resultset_get_url_idx)
PRIM2(cadmiumjdbc_resultset_get_url_name)
PRIM1(cadmiumjdbc_resultset_get_warnings)
PRIM1(cadmiumjdbc_resultset_insert_row)
PRIM1(cadmiumjdbc_resultset_is_after_last)
PRIM1(cadmiumjdbc_resultset_is_before_first)
PRIM1(cadmiumjdbc_resultset_is_closed)
PRIM1(cadmiumjdbc_resultset_is_first)
PRIM1(cadmiumjdbc_resultset_is_last)
PRIM1(cadmiumjdbc_resultset_last)
PRIM1(cadmiumjdbc_resultset_move_to_current_row)
PRIM1(cadmiumjdbc_resultset_move_to_insert_row)
PRIM1(cadmiumjdbc_resultset_next)
PRIM1(cadmiumjdbc_resultset_previous)
PRIM1(cadmiumjdbc_resultset_refresh_row)
PRIM2(cadmiumjdbc_resultset_relative)
PRIM1(cadmiumjdbc_resultset_row_deleted)
PRIM1(cadmiumjdbc_resultset_row_inserted)
PRIM1(cadmiumjdbc_resultset_row_updated)
PRIM2(cadmiumjdbc_resultset_set_fetch_direction)
PRIM2(cadmiumjdbc_resultset_set_fetch_size)
PRIM3(cadmiumjdbc_resultset_update_array_idx)
PRIM3(cadmiumjdbc_resultset_update_array_name)
PRIM3(cadmiumjdbc_resultset_update_ascii_stream_idx)
PRIM3(cadmiumjdbc_resultset_update_ascii_stream_name)
PRIM4(cadmiumjdbc_resultset_update_ascii_stream_length_idx)
PRIM4(cadmiumjdbc_resultset_update_ascii_stream_length_name)
PRIM4(cadmiumjdbc_resultset_update_ascii_stream_length64_idx)
PRIM4(cadmiumjdbc_resultset_update_ascii_stream_length64_name)
PRIM3(cadmiumjdbc_resultset_update_big_decimal_idx)
PRIM3(cadmiumjdbc_resultset_update_big_decimal_name)
PRIM3(cadmiumjdbc_resultset_update_binary_stream_idx)
PRIM3(cadmiumjdbc_resultset_update_binary_stream_name)
PRIM4(cadmiumjdbc_resultset_update_binary_stream_length_idx)
PRIM4(cadmiumjdbc_resultset_update_binary_stream_length_name)
PRIM4(cadmiumjdbc_resultset_update_binary_stream_length64_idx)
PRIM4(cadmiumjdbc_resultset_update_binary_stream_length64_name)
PRIM3(cadmiumjdbc_resultset_update_blob_idx)
PRIM3(cadmiumjdbc_resultset_update_blob_name)
PRIM3(cadmiumjdbc_resultset_update_boolean_idx)
PRIM3(cadmiumjdbc_resultset_update_boolean_name)
PRIM3(cadmiumjdbc_resultset_update_byte_idx)
PRIM3(cadmiumjdbc_resultset_update_byte_name)
PRIM3(cadmiumjdbc_resultset_update_bytes_idx)
PRIM3(cadmiumjdbc_resultset_update_bytes_name)
PRIM3(cadmiumjdbc_resultset_update_clob_idx)
PRIM3(cadmiumjdbc_resultset_update_clob_name)
PRIM3(cadmiumjdbc_resultset_update_date_idx)
PRIM3(cadmiumjdbc_resultset_update_date_name)
PRIM3(cadmiumjdbc_resultset_update_double_idx)
PRIM3(cadmiumjdbc_resultset_update_double_name)
PRIM3(cadmiumjdbc_resultset_update_float_idx)
PRIM3(cadmiumjdbc_resultset_update_float_name)
PRIM3(cadmiumjdbc_resultset_update_int_idx)
PRIM3(cadmiumjdbc_resultset_update_int_name)
PRIM3(cadmiumjdbc_resultset_update_long_idx)
PRIM3(cadmiumjdbc_resultset_update_long_name)
PRIM3(cadmiumjdbc_resultset_update_nclob_idx)
PRIM3(cadmiumjdbc_resultset_update_nclob_name)
PRIM3(cadmiumjdbc_resultset_update_nstring_idx)
PRIM3(cadmiumjdbc_resultset_update_nstring_name)
PRIM3(cadmiumjdbc_resultset_update_object_idx)
PRIM3(cadmiumjdbc_resultset_update_object_name)
PRIM4(cadmiumjdbc_resultset_update_object_scale_idx)
PRIM4(cadmiumjdbc_resultset_update_object_scale_name)
PRIM3(cadmiumjdbc_resultset_update_ref_idx)
PRIM3(cadmiumjdbc_resultset_update_ref_name)
PRIM1(cadmiumjdbc_resultset_update_row)
PRIM3(cadmiumjdbc_resultset_update_row_id_idx)
PRIM3(cadmiumjdbc_resultset_update_row_id_name)
PRIM3(cadmiumjdbc_resultset_update_short_idx)
PRIM3(cadmiumjdbc_resultset_update_short_name)
PRIM3(cadmiumjdbc_resultset_update_sqlxml_idx)
PRIM3(cadmiumjdbc_resultset_update_sqlxml_name)
PRIM3(cadmiumjdbc_resultset_update_string_idx)
PRIM3(cadmiumjdbc_resultset_update_string_name)
PRIM3(cadmiumjdbc_resultset_update_time_idx)
PRIM3(cadmiumjdbc_resultset_update_time_name)
PRIM3(cadmiumjdbc_resultset_update_timestamp_idx)
PRIM3(cadmiumjdbc_resultset_update_timestamp_name)


/* Primitives from RowIds */

PRIM2(cadmiumjdbc_rowid_equals)
PRIM1(cadmiumjdbc_rowid_get_bytes)
PRIM1(cadmiumjdbc_rowid_hash_code)
PRIM1(cadmiumjdbc_rowid_to_string)


/* Primitives from SQLXMLs */

PRIM1(cadmiumjdbc_sqlxml_free)
PRIM1(cadmiumjdbc_sqlxml_get_binary_stream)
PRIM1(cadmiumjdbc_sqlxml_get_string)
PRIM1(cadmiumjdbc_sqlxml_set_binary_stream)
PRIM2(cadmiumjdbc_sqlxml_set_string)


/* Primitives from Savepoints */

PRIM1(cadmiumjdbc_savepoint_get_savepoint_id)
PRIM1(cadmiumjdbc_savepoint_get_savepoint_name)


/* Primitives from Statements */

PRIM2(cadmiumjdbc_statement_add_batch)
PRIM1(cadmiumjdbc_statement_cancel)
PRIM1(cadmiumjdbc_statement_clear_batch)
PRIM1(cadmiumjdbc_statement_clear_warnings)
PRIM1(cadmiumjdbc_statement_close)
PRIM2(cadmiumjdbc_statement_execute)
PRIM3(cadmiumjdbc_statement_execute_autogen)
PRIM3(cadmiumjdbc_statement_execute_idx)
PRIM3(cadmiumjdbc_statement_execute_name)
PRIM1(cadmiumjdbc_statement_execute_batch)
PRIM2(cadmiumjdbc_statement_execute_query)
PRIM2(cadmiumjdbc_statement_execute_update)
PRIM3(cadmiumjdbc_statement_execute_update_autogen)
PRIM3(cadmiumjdbc_statement_execute_update_idx)
PRIM3(cadmiumjdbc_statement_execute_update_name)
PRIM1(cadmiumjdbc_statement_get_fetch_direction)
PRIM1(cadmiumjdbc_statement_get_fetch_size)
PRIM1(cadmiumjdbc_statement_get_generated_keys)
PRIM1(cadmiumjdbc_statement_get_max_field_size)
PRIM1(cadmiumjdbc_statement_get_max_rows)
PRIM1(cadmiumjdbc_statement_get_more_results)
PRIM2(cadmiumjdbc_statement_get_more_results_current)
PRIM1(cadmiumjdbc_statement_get_query_timeout)
PRIM1(cadmiumjdbc_statement_get_result_set)
PRIM1(cadmiumjdbc_statement_get_result_set_concurrency)
PRIM1(cadmiumjdbc_statement_get_result_set_holdability)
PRIM1(cadmiumjdbc_statement_get_result_set_type)
PRIM1(cadmiumjdbc_statement_get_update_count)
PRIM1(cadmiumjdbc_statement_get_warnings)
PRIM1(cadmiumjdbc_statement_is_closed)
PRIM1(cadmiumjdbc_statement_is_poolable)
PRIM2(cadmiumjdbc_statement_set_cursor_name)
PRIM2(cadmiumjdbc_statement_set_escape_processing)
PRIM2(cadmiumjdbc_statement_set_fetch_direction)
PRIM2(cadmiumjdbc_statement_set_fetch_size)
PRIM2(cadmiumjdbc_statement_set_max_field_size)
PRIM2(cadmiumjdbc_statement_set_max_rows)
PRIM2(cadmiumjdbc_statement_set_poolable)
PRIM2(cadmiumjdbc_statement_set_query_timeout)


/* Primitives from Structs */

PRIM1(cadmiumjdbc_struct_get_attributes)
PRIM1(cadmiumjdbc_struct_get_sql_type_name)


/* Primitives from Times */

PRIM1(cadmiumjdbc_time_make)
PRIM1(cadmiumjdbc_time_make_of_int64)
PRIM1(cadmiumjdbc_time_make_of_string)
PRIM1(cadmiumjdbc_time_get_time)
PRIM2(cadmiumjdbc_time_set_time)
PRIM1(cadmiumjdbc_time_to_string)


/* Primitives from Timestamps */

PRIM1(cadmiumjdbc_timestamp_make)
PRIM1(cadmiumjdbc_timestamp_make_of_int64)
PRIM1(cadmiumjdbc_timestamp_make_of_string)
PRIM2(cadmiumjdbc_timestamp_after)
PRIM2(cadmiumjdbc_timestamp_before)
PRIM2(cadmiumjdbc_timestamp_compare_to)
PRIM1(cadmiumjdbc_timestamp_get_nanos)
PRIM1(cadmiumjdbc_timestamp_get_time)
PRIM2(cadmiumjdbc_timestamp_set_nanos)
PRIM2(cadmiumjdbc_timestamp_set_time)
PRIM1(cadmiumjdbc_timestamp_to_string)
