/*
 * This file is part of Cadmium.
 * Copyright (C) 2007-2009 Xavier Clerc.
 *
 * Cadmium is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Cadmium is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package fr.x9c.cadmium.kernel;

/**
 * This interface defines the positions of fields in their respective debugging
 * records.
 *
 * @author <a href="mailto:cadmium@x9c.fr">Xavier Clerc</a>
 * @version 1.0
 * @since 1.0
 */
interface BackTrace {

    /**
     * Location of <i>EV_POS</i> field in the <i>Instruct.debug_event</i> record.
     */
    int EV_POS = 0;

    /**
     * Location of <i>EV_MODULE</i> field in the <i>Instruct.debug_event</i> record.
     */
    int EV_MODULE = 1;

    /**
     * Location of <i>EV_LOC</i> field in the <i>Instruct.debug_event</i> record.
     */
    int EV_LOC = 2;

    /**
     * Location of <i>EV_KIND</i> field in the <i>Instruct.debug_event</i> record.
     */
    int EV_KIND = 3;

    /**
     * Location of <i>LOC_START</i> field in the <i>Location.t</i> record.
     */
    int LOC_START = 0;

    /**
     * Location of <i>LOC_END</i> field in the <i>Location.t</i> record.
     */
    int LOC_END = 1;

    /**
     * Location of <i>LOC_GHOST</i> field in the <i>Location.t</i> record.
     */
    int LOC_GHOST = 2;

    /**
     * Location of <i>POS_FNAME</i> field in the <i>Lexing.position</i> record.
     */
    int POS_FNAME = 0;

    /**
     * Location of <i>POS_LNUM</i> field in the <i>Lexing.position</i> record.
     */
    int POS_LNUM = 1;

    /**
     * Location of <i>POS_BOL</i> field in the <i>Lexing.position</i> record.
     */
    int POS_BOL = 2;

    /**
     * Location of <i>POS_CNUM</i> field in the <i>Lexing.position</i> record.
     */
    int POS_CNUM = 3;

} // end interface 'BackTrace'
