/*
 * This file is part of Cadmium.
 * Copyright (C) 2007-2009 Xavier Clerc.
 *
 * Cadmium is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Cadmium is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package fr.x9c.cadmium.primitives.graph;

import fr.x9c.cadmium.kernel.CodeRunner;
import fr.x9c.cadmium.kernel.Fail;
import fr.x9c.cadmium.kernel.Primitive;
import fr.x9c.cadmium.kernel.PrimitiveProvider;
import fr.x9c.cadmium.kernel.Value;

/**
 * This class provides the implementation of color-related primitives.
 *
 * @author <a href="mailto:cadmium@x9c.fr">Xavier Clerc</a>
 * @version 1.0
 * @since 1.0
 */
@PrimitiveProvider
public final class Color {


    /**
     * No instance of this class.
     */
    private Color() {
    } // end empty constructor

    /**
     * Sets the color for drawing.
     * @param ctxt context
     * @param vrgb new drawing color in RGB format
     * @return <i>unit</i>
     * @throws Fail.Exception if the graph library has not been initialized
     */
    @Primitive
    public static Value caml_gr_set_color(final CodeRunner ctxt,
                                          final Value vrgb)
        throws Fail.Exception {
        GraphSlot.checkGraph(ctxt).setColor(new java.awt.Color(vrgb.asLong()));
        return Value.UNIT;
    } // end method 'caml_gr_set_color(CodeRunner, Value)'

} // end class 'Color'
