/*
 * This file is part of Cadmium.
 * Copyright (C) 2007-2009 Xavier Clerc.
 *
 * Cadmium is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Cadmium is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package fr.x9c.cadmium.primitives.graph;

import java.util.concurrent.atomic.AtomicLong;

import fr.x9c.cadmium.kernel.Block;
import fr.x9c.cadmium.kernel.CodeRunner;
import fr.x9c.cadmium.kernel.Fail;
import fr.x9c.cadmium.kernel.Primitive;
import fr.x9c.cadmium.kernel.PrimitiveProvider;
import fr.x9c.cadmium.kernel.Value;

/**
 * This class implements all primitives for 'GraphicsX11' module.
 * These are fake implementaion with no effect.
 *
 * @author <a href="mailto:cadmium@x9c.fr">Xavier Clerc</a>
 * @version 1.0
 * @since 1.0
 */
@PrimitiveProvider
public final class SubWindow {

    /**
     * Next identifier for subwindow, shared among code runners
     * (this is not a problem as these identifiers are fake).
     */
    private static final AtomicLong ID = new AtomicLong(1);

    /**
     * No instance of this class.
     */
    private SubWindow() {
    } // end empty constructor

    /**
     * Does nothing.
     * @param ctxt context
     * @param vx ignored
     * @param vy ignored
     * @param width ignored
     * @param height ignored
     * @return (fake) window id
     * @throws Fail.Exception if <i>Graphics</i> module has not been initialized
     */
    @Primitive
    public static Value caml_gr_open_subwindow(final CodeRunner ctxt,
                                               final Value vx,
                                               final Value vy,
                                               final Value width,
                                               final Value height)
        throws Fail.Exception {
        GraphSlot.checkGraph(ctxt);
        return Value.createFromBlock(Block.createString(Long.toString(SubWindow.ID.getAndIncrement())));
    } // end method 'caml_gr_open_subwindow(CodeRunner, Value, Value, ...)'

    /**
     * Does nothing.
     * @param ctxt context
     * @param wid ignored
     * @return <i>unit</i>
     * @throws Fail.Exception if <i>Graphics</i> module has not been initialized
     */
    @Primitive
    public static Value caml_gr_close_subwindow(final CodeRunner ctxt,
                                                final Value wid)
        throws Fail.Exception {
        GraphSlot.checkGraph(ctxt);
        return Value.UNIT;
    } // end method 'caml_gr_close_subwindow(CodeRunner, Value)'

} // end class 'SubWindow'
