/*
 * This file is part of Cadmium.
 * Copyright (C) 2007-2009 Xavier Clerc.
 *
 * Cadmium is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Cadmium is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package fr.x9c.cadmium.primitives.labltk;

import fr.x9c.cadmium.kernel.CodeRunner;
import fr.x9c.cadmium.kernel.Value;

import tcl.lang.TimerHandler;

/**
 * This class implements a timer calling a callback upon timer exhaustion.
 *
 * @author <a href="mailto:cadmium@x9c.fr">Xavier Clerc</a>
 * @version 1.3
 * @since 1.3
 */
public final class CamlTimer extends TimerHandler {

    /** Code runner used to execute callback. */
    private final CodeRunner codeRunner;

    /** Slot used to retrieve handler. */
    private final TKSlot slot;

    /** Callback identifier. */
    private final int id;

    /**
     * Builds a Timer.
     * @param cr used to execute callback - should not be <tt>null</tt>
     * @param s used to retrieve handler - should not be <tt>null</tt>
     * @param i callback identifier
     * @param m timer duration in milliseconds
     */
    public CamlTimer(final CodeRunner cr, final TKSlot s, final int i, final int m) {
        super(s.getInterpreter().getNotifier(), m);
        assert cr != null : "null cr";
        assert s != null : "null s";
        this.codeRunner= cr;
        this.slot = s;
        this.id = i;
    } // end constructor(CodeRunner, TKSlot, int, int)

    /**
     * Method called when a timer is exhasuted.
     */
    public void processTimerEvent() {
        try {
            this.codeRunner.callback(this.slot.getHandlerCode(),
                                     Value.createFromLong(this.id),
                                     Value.EMPTY_LIST);
        } catch (final Throwable t) {
            // nothing to be done
        } // end try/catch
    } // end method 'processTimerEvent()'

} // end class 'CamlTimer'
