/*
 * This file is part of Cadmium.
 * Copyright (C) 2007-2009 Xavier Clerc.
 *
 * Cadmium is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Cadmium is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package fr.x9c.cadmium.primitives.labltk;

import fr.x9c.cadmium.kernel.CodeRunner;
import fr.x9c.cadmium.kernel.Fail;
import fr.x9c.cadmium.kernel.Primitive;
import fr.x9c.cadmium.kernel.PrimitiveProvider;
import fr.x9c.cadmium.kernel.Value;

/**
 * Implements all primitives from 'cltkFile.c'.
 *
 * @author <a href="mailto:cadmium@x9c.fr">Xavier Clerc</a>
 * @version 1.3
 * @since 1.3
 */
@PrimitiveProvider
public final class CltkFile {

    /**
     * No instance of this class.
     */
    private CltkFile() {
    } // end empty constructor

    /**
     * Registers a callback to be called when data is available on a file descriptor.
     * @param ctxt context
     * @param fd file descriptor
     * @param cbid callback identifier
     * @return <i>unit</i>
     */
    @Primitive
    public static Value camltk_add_file_input(final CodeRunner ctxt,
                                              final Value fd,
                                              final Value cbid)
        throws Fail.Exception {
        final TKSlot slot = TKSlot.checkInit(ctxt);
        slot.createInputWaiterThread(ctxt, fd.asLong(), cbid.asLong());
        return Value.UNIT;
    } // end method 'camltk_add_file_input(CodeRunner, Value, Value)'

    /**
     * Unregisters a callback to be called when data is available on a file descriptor.
     * @param ctxt context
     * @param fd file descriptor
     * @param cbid callback identifier
     * @return <i>unit</i>
     */
    @Primitive
    public static Value camltk_rem_file_input(final CodeRunner ctxt,
                                              final Value fd,
                                              final Value cbid)
        throws Fail.Exception {
        final TKSlot slot = TKSlot.checkInit(ctxt);
        slot.removeInputWaiterThread(fd.asLong(), cbid.asLong());
        return Value.UNIT;
    } // end method 'camltk_rem_file_input(CodeRunner, Value, Value)'

    /**
     * Does nothing.
     * @param ctxt context
     * @param fd ignored
     * @param cbid ignored
     * @return <i>unit</i>
     */
    @Primitive
    public static Value camltk_add_file_output(final CodeRunner ctxt,
                                               final Value fd,
                                               final Value cbid)
        throws Fail.Exception {
        TKSlot.checkInit(ctxt);
        return Value.UNIT;
    } // end method 'camltk_add_file_output(CodeRunner, Value, Value)'

    /**
     * Does nothing.
     * @param ctxt context
     * @param fd ignored
     * @param cbid ignored
     * @return <i>unit</i>
     */
    @Primitive
    public static Value camltk_rem_file_output(final CodeRunner ctxt,
                                               final Value fd,
                                               final Value cbid)
        throws Fail.Exception {
        TKSlot.checkInit(ctxt);
        return Value.UNIT;
    } // end method 'camltk_rem_file_output(CodeRunner, Value, Value)'

} // end class 'CltkFile'
