/*
 * This file is part of Cadmium.
 * Copyright (C) 2007-2009 Xavier Clerc.
 *
 * Cadmium is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Cadmium is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package fr.x9c.cadmium.primitives.labltk;

import java.awt.Window;

import fr.x9c.cadmium.kernel.CodeRunner;
import fr.x9c.cadmium.kernel.Fail;
import fr.x9c.cadmium.kernel.Primitive;
import fr.x9c.cadmium.kernel.PrimitiveProvider;
import fr.x9c.cadmium.kernel.Value;

import com.onemoonscientific.swank.Widgets;

import tcl.lang.TclException;

/**
 * Implements all primitives from 'cltkWait.c'.
 *
 * @author <a href="mailto:cadmium@x9c.fr">Xavier Clerc</a>
 * @version 1.3
 * @since 1.3
 */
@PrimitiveProvider
public final class CltkWait {

    /**
     * No instance of this class.
     */
    private CltkWait() {
    } // end empty constructor

    /**
     * Registers a callback to be executed when a window is made visible.
     * @param ctxt context
     * @param win window name
     * @param cbid callback identifier
     * @return <i>unit</i>
     */
    @Primitive
    public static Value camltk_wait_vis(final CodeRunner ctxt,
                                        final Value win,
                                        final Value cbid)
        throws Fail.Exception {
        CltkWait.addWindowListener(ctxt, true, win.asBlock().asString(), cbid.asLong());
        return Value.UNIT;
    } // end method 'camltk_wait_vis(CodeRunner, Value, Value)'

    /**
     * Registers a callback to be executed when a window is closed.
     * @param ctxt context
     * @param win window name
     * @param cbid callback identifier
     * @return <i>unit</i>
     */
    @Primitive
    public static Value camltk_wait_des(final CodeRunner ctxt,
                                        final Value win,
                                        final Value cbid)
        throws Fail.Exception {
        CltkWait.addWindowListener(ctxt, false, win.asBlock().asString(), cbid.asLong());
        return Value.UNIT;
    } // end method 'camltk_wait_des(CodeRunner, Value, Value)'

    /**
     * Registers a callback to be executed when a window is either opened or closed.
     * @param ctxt context
     * @param vis whether the callback should be called upon window opening
     * @param name window name
     * @param id callback identifier
     * @return <i>unit</i>
     */
    private static void addWindowListener(final CodeRunner ctxt,
                                          final boolean vis,
                                          final String name,
                                          final int id)
        throws Fail.Exception {
        final TKSlot slot = TKSlot.checkInit(ctxt);
        try {
            final Object obj = Widgets.get(slot.getInterpreter(), name);
            if (obj instanceof Window) {
                final Window win = (Window) obj;
                win.addWindowListener(new CamlWindowAdapter(ctxt, slot, vis, id));
            } // end if
        } catch (final TclException te) {
            slot.tkError(te);
        } // end catch
    } // end method 'addWindowListener(CodeRunner, boolean, String, int)'

} // end class 'CltkWait'
