/*
 * This file is part of Cadmium.
 * Copyright (C) 2007-2009 Xavier Clerc.
 *
 * Cadmium is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Cadmium is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package fr.x9c.cadmium.primitives.stdlib;

import fr.x9c.cadmium.kernel.CodeRunner;
import fr.x9c.cadmium.kernel.Fail;
import fr.x9c.cadmium.kernel.Primitive;
import fr.x9c.cadmium.kernel.PrimitiveProvider;
import fr.x9c.cadmium.kernel.Value;

/**
 * Implements all primitives from 'terminfo.c'.
 *
 * @author <a href="mailto:cadmium@x9c.fr">Xavier Clerc</a>
 * @version 1.0
 * @since 1.0
 */
@PrimitiveProvider
public final class Terminfo {

    /** Indicates that terminal is not available. */
    private static final Value BAD_TERM = Value.ONE;

    /**
     * No instance of this class.
     */
    private Terminfo() {
    } // end empty constructor

    /**
     * Returns {@link fr.x9c.cadmium.primitives.stdlib.Terminfo#BAD_TERM},
     * meaning that terminal commands are not available.
     * @param ctxt context
     * @param channel terminal
     * @return {@link fr.x9c.cadmium.primitives.stdlib.Terminfo#BAD_TERM}
     */
    @Primitive
    public static Value caml_terminfo_setup(final CodeRunner ctxt,
                                            final Value channel) {
        return Terminfo.BAD_TERM;
    } // end method 'caml_terminfo_setup(CodeRunner, Value)'

    /**
     * Always raises <i>Invalid_argument("Terminfo.backup")</i>.
     * @param ctxt context
     * @param lines ignored
     * @return never (would return <i>unit</i>)
     * @throws Fail.Exception always
     */
    @Primitive
    public static Value caml_terminfo_backup(final CodeRunner ctxt,
                                             final Value lines)
        throws Fail.Exception {
        Fail.invalidArgument("Terminfo.backup");
        return Value.UNIT; // never reached
    } // end method 'caml_terminfo_backup(CodeRunner, Value)'

    /**
     * Always raises <i>Invalid_argument("Terminfo.standout")</i>.
     * @param ctxt context
     * @param start ignored
     * @return never (would return <i>unit</i>)
     * @throws Fail.Exception always
     */
    @Primitive
    public static Value caml_terminfo_standout(final CodeRunner ctxt,
                                               final Value start)
        throws Fail.Exception {
        Fail.invalidArgument("Terminfo.standout");
        return Value.UNIT; // never reached
    } // end method 'caml_terminfo_standout(CodeRunner, Value)'

    /**
     * Always raises <i>Invalid_argument("Terminfo.resume")</i>.
     * @param ctxt context
     * @param lines ignored
     * @return never (would return <i>unit</i>)
     * @throws Fail.Exception always
     */
    @Primitive
    public static Value caml_terminfo_resume(final CodeRunner ctxt,
                                             final Value lines)
        throws Fail.Exception {
        Fail.invalidArgument("Terminfo.resume");
        return Value.UNIT; // never reached
    } // end method 'caml_terminfo_resume(CodeRunner, Value)'

} // end class 'Terminfo'
