/*
 * This file is part of Cadmium.
 * Copyright (C) 2007-2009 Xavier Clerc.
 *
 * Cadmium is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Cadmium is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package fr.x9c.cadmium.primitives.unix;

import java.net.InetAddress;
import java.net.UnknownHostException;

import fr.x9c.cadmium.kernel.CodeRunner;
import fr.x9c.cadmium.kernel.Fail;
import fr.x9c.cadmium.kernel.Primitive;
import fr.x9c.cadmium.kernel.PrimitiveProvider;
import fr.x9c.cadmium.kernel.Value;

/**
 * This class provides implementation for 'unix_inet_addr_of_string' primitive.
 *
 * @author <a href="mailto:cadmium@x9c.fr">Xavier Clerc</a>
 * @version 1.0
 * @since 1.0
 */
@PrimitiveProvider
public final class Addrofstr {

    /**
     * No instance of this class.
     */
    private Addrofstr() {
    } // end empty constructor

    /**
     * Converts a <i>a.b.c.d</i> string into an address.
     * @param ctxt context
     * @param s string to convert
     * @return corresponding address
     * @throws Fail.Exception if address conversion fails
     */
    @Primitive
    public static Value unix_inet_addr_of_string(final CodeRunner ctxt,
                                                 final Value s)
        throws Fail.Exception {
        try {
            return Unix.createInetAddr(ctxt, InetAddress.getByName(s.asBlock().asString()));
        } catch (final UnknownHostException uhe) {
            Fail.failWith("inet_addr_of_string");
            return Value.UNIT; // never reached
        } // end try/catch
    } // end method 'unix_inet_addr_of_string(CodeRunner, Value)'

} // end class 'Addrofstr'
