/*
 * This file is part of Cadmium.
 * Copyright (C) 2007-2009 Xavier Clerc.
 *
 * Cadmium is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Cadmium is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package fr.x9c.cadmium.primitives.unix;

import fr.x9c.cadmium.kernel.CodeRunner;
import fr.x9c.cadmium.kernel.Fail;
import fr.x9c.cadmium.kernel.Primitive;
import fr.x9c.cadmium.kernel.PrimitiveProvider;
import fr.x9c.cadmium.kernel.Value;

/**
 * This class provides implementation for file control-related primitives.
 *
 * @author <a href="mailto:cadmium@x9c.fr">Xavier Clerc</a>
 * @version 1.0
 * @since 1.0
 */
@PrimitiveProvider
public final class Fcntl {

    /**
     * No instance of this class.
     */
    private Fcntl() {
    } // end empty constructor

    /**
     * No implementation of this primitive.
     * @param ctxt context
     * @param fd ignored
     * @return <i>unit</i>
     * @throws Fail.Exception always
     */
    @Primitive
    public static Value unix_set_nonblock(final CodeRunner ctxt,
                                          final Value fd)
        throws Fail.Exception {
        Fail.invalidArgument("Unix.set_nonblock not implemented");
        return Value.UNIT; // never reached
    } // end method 'unix_set_nonblock(CodeRunner, Value)'

    /**
     * No implementation of this primitive.
     * @param ctxt context
     * @param fd ignored
     * @return <i>unit</i>
     * @throws Fail.Exception always
     */
    @Primitive
    public static Value unix_clear_nonblock(final CodeRunner ctxt,
                                            final Value fd)
        throws Fail.Exception {
        Fail.invalidArgument("Unix.clear_nonblock not implemented");
        return Value.UNIT; // never reached
    } // end method 'unix_clear_nonblock(CodeRunner, Value)'

    /**
     * No implementation of this primitive.
     * @param ctxt context
     * @param fd ignored
     * @return <i>unit</i>
     * @throws Fail.Exception always
     */
    @Primitive
    public static Value unix_set_close_on_exec(final CodeRunner ctxt,
                                               final Value fd)
        throws Fail.Exception {
        Fail.invalidArgument("Unix.set_close_on_exec not implemented");
        return Value.UNIT; // never reached
    } // end method 'unix_set_close_on_exec(CodeRunner, Value)'

    /**
     * No implementation of this primitive.
     * @param ctxt context
     * @param fd ignored
     * @return <i>unit</i>
     * @throws Fail.Exception always
     */
    @Primitive
    public static Value unix_clear_close_on_exec(final CodeRunner ctxt,
                                                 final Value fd)
        throws Fail.Exception {
        Fail.invalidArgument("Unix.clear_close_on_exec not implemented");
        return Value.UNIT; // never reached
    } // end method 'unix_clear_close_on_exec(CodeRunner, Value)'

} // end class 'Fcntl'
