/*
 * This file is part of Cadmium.
 * Copyright (C) 2007-2009 Xavier Clerc.
 *
 * Cadmium is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Cadmium is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package fr.x9c.cadmium.primitives.unix;

import fr.x9c.cadmium.kernel.Block;
import fr.x9c.cadmium.kernel.CodeRunner;
import fr.x9c.cadmium.kernel.Fail;
import fr.x9c.cadmium.kernel.Primitive;
import fr.x9c.cadmium.kernel.PrimitiveProvider;
import fr.x9c.cadmium.kernel.Value;

/**
 * This class provides implementation for 'unix_opendir' primitive.
 *
 * @author <a href="mailto:cadmium@x9c.fr">Xavier Clerc</a>
 * @version 1.0
 * @since 1.0
 */
@PrimitiveProvider
public final class Opendir {

    /**
     * No instance of this class.
     */
    private Opendir() {
    } // end empty constructor

    /**
     * Opens a directory for content listing.
     * @param ctxt context
     * @param path directory
     * @return directory listing (handle)
     * @throws Fail.Exception if an error occurs while trying to retrieve
     *                        directory content
     */
    @Primitive
    public static Value unix_opendir(final CodeRunner ctxt,
                                     final Value path)
        throws Fail.Exception {
        final Block res = Block.createBlock(1, Block.ABSTRACT_TAG);
        res.setCustom(new Unix.DirList(ctxt,
                                       ctxt.getContext().getRealFile(path)));
        return Value.createFromBlock(res);
    } // end method 'unix_opendir(CodeRunner, Value)'

} // end class 'Opendir'
