/*
 * This file is part of Cadmium.
 * Copyright (C) 2007-2009 Xavier Clerc.
 *
 * Cadmium is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Cadmium is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package fr.x9c.cadmium.primitives.unix;

import fr.x9c.cadmium.kernel.Block;
import fr.x9c.cadmium.kernel.CodeRunner;
import fr.x9c.cadmium.kernel.Fail;
import fr.x9c.cadmium.kernel.Primitive;
import fr.x9c.cadmium.kernel.PrimitiveProvider;
import fr.x9c.cadmium.kernel.Value;

/**
 * This class provides implementation for 'unix_readdir' primitive.
 *
 * @author <a href="mailto:cadmium@x9c.fr">Xavier Clerc</a>
 * @version 1.0
 * @since 1.0
 */
@PrimitiveProvider
public final class Readdir {

    /**
     * No instance of this class.
     */
    private Readdir() {
    } // end empty constructor

    /**
     * Returns the next entry in directory listing.
     * @param ctxt context
     * @param d directory listing
     * @return next entry in directory listing, as a string
     * @throws Fail.Exception raises <i>End_of_file</i> if all entries have
     *                        already been returned
     */
    @Primitive
    public static Value unix_readdir(final CodeRunner ctxt,
                                     final Value d)
        throws Fail.Exception {
        return Value.createFromBlock(Block.createString(((Unix.DirList) d.asBlock().asCustom()).next()));
    } // end method 'unix_readdir(CodeRunner, Value)'

} // end class 'Readdir'
