/*
 * This file is part of Cadmium.
 * Copyright (C) 2007-2009 Xavier Clerc.
 *
 * Cadmium is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Cadmium is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package fr.x9c.cadmium.primitives.unix;

import java.io.File;

import fr.x9c.cadmium.kernel.CodeRunner;
import fr.x9c.cadmium.kernel.Context;
import fr.x9c.cadmium.kernel.Fail;
import fr.x9c.cadmium.kernel.Primitive;
import fr.x9c.cadmium.kernel.PrimitiveProvider;
import fr.x9c.cadmium.kernel.Value;

/**
 * This class provides implementation for 'unix_rename' primitive.
 *
 * @author <a href="mailto:cadmium@x9c.fr">Xavier Clerc</a>
 * @version 1.0
 * @since 1.0
 */
@PrimitiveProvider
public final class Rename {

    /**
     * No instance of this class.
     */
    private Rename() {
    } // end empty constructor

    /**
     * Renames a file.
     * @param ctxt context
     * @param path1 file to rename
     * @param path2 path to rename to
     * @return <i>unit</i>
     * @throws Fail.Exception if file cannot be renamed
     */
    @Primitive
    public static Value unix_rename(final CodeRunner ctxt,
                                    final Value path1,
                                    final Value path2)
        throws Fail.Exception {
        final Context c = ctxt.getContext();
        final File from = c.getRealFile(path1);
        final File to = c.getRealFile(path2);
        if (!from.renameTo(to)) {
            Unix.fail(ctxt, "rename", "cannot rename file");
        } // end if
        return Value.UNIT;
    } // end method 'unix_rename(CodeRunner, Value, Value)'

} // end class 'Rename'
