/*
 * This file is part of Cadmium.
 * Copyright (C) 2007-2009 Xavier Clerc.
 *
 * Cadmium is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Cadmium is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package fr.x9c.cadmium.primitives.unix;

import fr.x9c.cadmium.kernel.CodeRunner;
import fr.x9c.cadmium.kernel.Fail;
import fr.x9c.cadmium.kernel.Primitive;
import fr.x9c.cadmium.kernel.PrimitiveProvider;
import fr.x9c.cadmium.kernel.Value;

/**
 * This class provides implementation for 'unix_rewinddir' primitive.
 *
 * @author <a href="mailto:cadmium@x9c.fr">Xavier Clerc</a>
 * @version 1.0
 * @since 1.0
 */
@PrimitiveProvider
public final class Rewinddir {

    /**
     * No instance of this class.
     */
    private Rewinddir() {
    } // end empty constructor

    /**
     * Resets the pointer of directory listing.
     * @param ctxt context
     * @param d directory listing
     * @return <i>unit</i>
     * @throws Fail.Exception if directory listing is closed
     */
    @Primitive
    public static Value unix_rewinddir(final CodeRunner ctxt,
                                       final Value d)
        throws Fail.Exception {
        ((Unix.DirList) d.asBlock().asCustom()).rewind();
        return Value.UNIT;
    } // end method 'unix_rewinddir(CodeRunner, Value)'

} // end class 'Rewinddir'
