/*
 * This file is part of Cadmium.
 * Copyright (C) 2007-2009 Xavier Clerc.
 *
 * Cadmium is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Cadmium is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package fr.x9c.cadmium.support.servlet;

import fr.x9c.cadmium.kernel.Value;

/**
 * Common services for listeners.
 *
 * @author <a href="mailto:cadmium@x9c.fr">Xavier Clerc</a>
 * @version 1.1
 * @since 1.1
 */
final class Listeners {

    /**
     * No instance of this class.
     */
    private Listeners() {
    } // end empty constructor

    /**
     * Runs a callback, with passed parameters, doing nothing if the callback
     * has not been registered. <br/>
     * <b>Exceptions are silently ignored and return value is discarded.</b>
     * @param cb callback to run - should not be <tt>null</tt>
     * @param args callback parameters
     */
    static void callback(final String cb, final Value... args) {
        assert cb != null : "null cb";
        if ((ByteCodeServlet.interpreter != null)
            && (ByteCodeServlet.interpreter.getContext().getCallback(cb) != null)) {
            try {
                ByteCodeServlet.interpreter.execute(cb, args);
            } catch (final Exception e) {
                // nothing to do
            } // end try/catch
        } else if ((AbstractNativeServlet.runner != null)
                   && (AbstractNativeServlet.runner.getContext().getCallback(cb) != null)) {
            try {
                final Value closure =
                    AbstractNativeServlet.runner.getContext().getCallback(cb);
                AbstractNativeServlet.runner.callback(closure, args);
            } catch (final Exception e) {
                // nothing to do
            } // end try/catch
        } // end if/elsif
    } // end method 'callback(String, Value...)'

} // end class 'Listeners'
