/*
 * This file is part of Cadmium.
 * Copyright (C) 2007-2009 Xavier Clerc.
 *
 * Cadmium is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Cadmium is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package fr.x9c.cadmium.support.servlet;

import javax.servlet.http.HttpSessionActivationListener;
import javax.servlet.http.HttpSessionEvent;

import fr.x9c.cadmium.primitives.cadmium.Cadmium;

/**
 * Listener whose behaviour is defined by callbacks registered using
 * <tt>Servlet.Listeners.register_session_activation_listener</tt>.
 *
 * @author <a href="mailto:cadmium@x9c.fr">Xavier Clerc</a>
 * @version 1.1
 * @since 1.1
 */
public final class SessionActivationListener
    implements HttpSessionActivationListener {

    /**
     * Empty constructor.
     */
    public SessionActivationListener() {
    } // end empty constructor

    /**
     * {@inheritDoc}
     */
    @Override
    public void sessionDidActivate(final HttpSessionEvent se) {
        Listeners.callback("Servlet.session_activation_listener.session_did_activate",
                           Cadmium.createObject(se.getSession()));
    } // end method 'sessionDidActivate(HttpSessionEvent)'

    /**
     * {@inheritDoc}
     */
    @Override
    public void sessionWillPassivate(final HttpSessionEvent se) {
        Listeners.callback("Servlet.session_activation_listener.session_will_passivate",
                           Cadmium.createObject(se.getSession()));
    } // end method 'sessionWillPassivate(HttpSessionEvent)'

} // end class 'SessionActivationListener'
