/*
 * This file is part of Cadmium.
 * Copyright (C) 2007-2009 Xavier Clerc.
 *
 * Cadmium is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Cadmium is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package fr.x9c.cadmium.support.servlet;

import javax.servlet.http.HttpSessionAttributeListener;
import javax.servlet.http.HttpSessionBindingEvent;

import fr.x9c.cadmium.kernel.Block;
import fr.x9c.cadmium.kernel.Value;
import fr.x9c.cadmium.primitives.cadmium.Cadmium;

/**
 * Listener whose behaviour is defined by callbacks registered using
 * <tt>Servlet.Listeners.register_session_attribute_listener</tt>.
 *
 * @author <a href="mailto:cadmium@x9c.fr">Xavier Clerc</a>
 * @version 1.1
 * @since 1.1
 */
public final class SessionAttributeListener
    implements HttpSessionAttributeListener {

    /**
     * Empty constructor.
     */
    public SessionAttributeListener() {
    } // end empty constructor

    /**
     * {@inheritDoc}
     */
    @Override
    public void attributeAdded(final HttpSessionBindingEvent se) {
        Listeners.callback("Servlet.session_attribute_listener.attribute_added",
                           Cadmium.createObject(se.getSession()),
                           Value.createFromBlock(Block.createString(se.getName())),
                           Cadmium.createObject(se.getValue()));
    } // end method 'attributeAdded(HttpSessionBindingEvent)'

    /**
     * {@inheritDoc}
     */
    @Override
    public void attributeRemoved(final HttpSessionBindingEvent se) {
        Listeners.callback("Servlet.session_attribute_listener.attribute_removed",
                           Cadmium.createObject(se.getSession()),
                           Value.createFromBlock(Block.createString(se.getName())),
                           Cadmium.createObject(se.getValue()));
    } // end method 'attributeRemoved(HttpSessionBindingEvent)'

    /**
     * {@inheritDoc}
     */
    @Override
    public void attributeReplaced(final HttpSessionBindingEvent se) {
        Listeners.callback("Servlet.session_attribute_listener.attribute_replaced",
                           Cadmium.createObject(se.getSession()),
                           Value.createFromBlock(Block.createString(se.getName())),
                           Cadmium.createObject(se.getValue()));
    } // end method 'attributeReplaced(HttpSessionBindingEvent)'

} // end class 'SessionAttributeListener'
