/*
 * This file is part of Cadmium.
 * Copyright (C) 2007-2009 Xavier Clerc.
 *
 * Cadmium is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Cadmium is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package fr.x9c.cadmium.support.values;

import fr.x9c.cadmium.kernel.Value;

/**
 * This class defines values of the <i>char</i> type.
 *
 * @author <a href="mailto:cadmium@x9c.fr">Xavier Clerc</a>
 * @version 1.0
 * @since 1.0
 */
public final class Char implements ToValue {

    /** The actual value. */
    private final int value;

    /**
     * Constructs a char value.
     * @param v char value - should be in 0..255
     */
    public Char(final int v) {
        assert (v >= 0) && (v <= 255) : "char value out of bounds";
        this.value = v;
    } // end constructor(int)

    /**
     * Returns the value, as an integer.
     * @return the value
     */
    public int get() {
        return this.value;
    } // end method 'get()'

    /**
     * {@inheritDoc}
     */
    @Override
    public Value toValue() {
        return Value.createFromLong(this.value);
    } // end method 'toValue()'

    /**
     * {@inheritDoc}
     */
    @Override
    public int hashCode() {
        return this.value;
    } // end method 'hashCode()'

    /**
     * {@inheritDoc}
     */
    @Override
    public boolean equals(final Object obj) {
        if (obj instanceof Char) {
            final Char that = (Char) obj;
            return this.value == that.value;
        } else {
            return false;
        } // end if/else
    } // end method 'equals(Object)'

    /**
     * {@inheritDoc}
     */
    @Override
    public String toString() {
        return Character.toString((char) this.value);
    } // end method 'toString()'

} // end class 'Char'
