/*
 * This file is part of Cadmium.
 * Copyright (C) 2007-2009 Xavier Clerc.
 *
 * Cadmium is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Cadmium is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package fr.x9c.cadmium.support.values;

import fr.x9c.cadmium.kernel.Block;
import fr.x9c.cadmium.kernel.Custom;
import fr.x9c.cadmium.kernel.Value;

/**
 * This class defines values of the <i>int64</i> type.
 *
 * @author <a href="mailto:cadmium@x9c.fr">Xavier Clerc</a>
 * @version 1.0
 * @since 1.0
 */
public final class Int64 implements ToValue {

    /** The actual value. */
    private final long value;

    /**
     * Constructs an integer value.
     * @param v integer value
     */
    public Int64(final long v) {
        this.value = v;
    } // end constructor(long)

    /**
     * Returns the value.
     * @return the value
     */
    public long get() {
        return this.value;
    } // end method 'get()'

    /**
     * {@inheritDoc}
     */
    @Override
    public Value toValue() {
        final Block res = Block.createCustom(Custom.INT_64_SIZE,
                                             Custom.INT_64_OPS);
        res.setInt64(this.value);
        return Value.createFromBlock(res);
    } // end method 'toValue()'

    /**
     * {@inheritDoc}
     */
    @Override
    public int hashCode() {
        return (int) this.value;
    } // end method 'hashCode()'

    /**
     * {@inheritDoc}
     */
    @Override
    public boolean equals(final Object obj) {
        if (obj instanceof Int64) {
            final Int64 that = (Int64) obj;
            return this.value == that.value;
        } else {
            return false;
        } // end if/else
    } // end method 'equals(Object)'

    /**
     * {@inheritDoc}
     */
    @Override
    public String toString() {
        return Long.toString(this.value);
    } // end method 'toString()'

} // end class 'Int64'
