/*
 * This file is part of Cadmium.
 * Copyright (C) 2007-2009 Xavier Clerc.
 *
 * Cadmium is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Cadmium is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package fr.x9c.cadmium.support.values;

import fr.x9c.cadmium.kernel.Block;
import fr.x9c.cadmium.kernel.Value;

/**
 * This class defines values of the <i>'a ref</i> type.
 *
 * @param <T> type of referenced element
 *
 * @author <a href="mailto:cadmium@x9c.fr">Xavier Clerc</a>
 * @version 1.0
 * @since 1.0
 */
public final class Reference<T extends ToValue> implements ToValue {

    /** The embedded value. */
    private T value;

    /**
     * Constructs a reference value.
     * @param v referenced value - should not be <tt>null</tt>
     */
    public Reference(final T v) {
        assert v != null : "null v";
        this.value = v;
    } // end constructor(T)

    /**
     * Returns the content of the reference value.
     * @return the content of the reference value
     */
    public T get() {
        return this.value;
    } // end method 'get()'

    /**
     * Changes the content of the reference value.
     * @param v new content - should not be <tt>null</tt>
     */
    public void set(final T v) {
        assert v != null : "null v";
        this.value = v;
    } // end method 'set(T)'

    /**
     * {@inheritDoc}
     */
    @Override
    public Value toValue() {
        final Block res = Block.createBlock(0, this.value.toValue());
        return Value.createFromBlock(res);
    } // end method 'toValue()'

    /**
     * {@inheritDoc}
     */
    @Override
    public int hashCode() {
        return this.value.hashCode();
    } // end method 'hashCode()'

    /**
     * {@inheritDoc}
     */
    @Override
    public boolean equals(final Object obj) {
        if (obj instanceof Reference) {
            final Reference<?> that = (Reference<?>) obj;
            return this.value.equals(that.value);
        } else {
            return false;
        } // end if/else
    } // end method 'equals(Object)'

    /**
     * {@inheritDoc}
     */
    @Override
    public String toString() {
        return "ref " + this.value.toString();
    } // end method 'toString()'

} // end class 'Reference'
