/*
 * This file is part of Cadmium.
 * Copyright (C) 2007-2009 Xavier Clerc.
 *
 * Cadmium is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Cadmium is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package fr.x9c.cadmium.util;

import java.io.IOException;
import java.io.OutputStream;
import java.io.Writer;

/**
 * This class implements an output stream that writes its output to a writer.
 *
 * @author <a href="mailto:cadmium@x9c.fr">Xavier Clerc</a>
 * @version 1.1
 * @since 1.1
 */
public final class OutputStreamToWriter extends OutputStream {

    /** Data destination. */
    private final Writer destination;

    /**
     * Creates a new output stream.
     * @param w the writer to which values are written - should not be <tt>null</tt>
     */
    public OutputStreamToWriter(final Writer w) {
        assert w != null : "null w";
        this.destination = w;
    } // end constructor(Writer)

    /**
     * {@inheritDoc}
     */
    @Override
    public void write(final int b) throws IOException {
        this.destination.write(b);
    } // end method 'write(int)'

} // end class 'OutputStreamToWriter'
