(*
 * This file is part of Cadmium.
 * Copyright (C) 2007-2009 Xavier Clerc.
 *
 * Cadmium is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Cadmium is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *)

(* Configuration *)

external is_debug_mode : unit -> bool =
  "cadmiumswixml_is_debug_mode"

external is_macosx : unit -> bool =
  "cadmiumswixml_is_macosx"

external is_macosx_supported : unit -> bool =
  "cadmiumswixml_is_macosx_supported"

external set_macosx_support : bool -> unit =
  "cadmiumswixml_set_macosx_support"

external set_default_locale : Cadmium.java_object -> unit =
  "cadmiumswixml_set_default_locale"

external set_resource_bundle_name : string -> unit =
  "cadmiumswixml_set_resource_bundle_name"

external set_app_frame : Cadmium.java_object -> unit =
  "cadmiumswixml_set_app_frame"

external get_app_frame : unit -> Cadmium.java_object =
  "cadmiumswixml_get_app_frame"


(* Engine construction *)

type engine = Cadmium.java_object

external make_engine : unit -> engine =
  "cadmiumswixml_make_engine"

external make_engine_from_resource : string -> engine =
  "cadmiumswixml_make_engine_from_resource"

external make_engine_from_client : Cadmium.java_object -> engine =
  "cadmiumswixml_make_engine_from_client"


(* Engine parameters *)

external get_client : engine -> Cadmium.java_object =
  "cadmiumswixml_get_client"

external set_classloader : engine -> Cadmium.java_object -> unit =
  "cadmiumswixml_set_classloader"

external get_classloader : engine -> Cadmium.java_object =
  "cadmiumswixml_get_classloader"

external set_locale : engine -> Cadmium.java_object -> unit =
  "cadmiumswixml_set_locale"

external set_resource_bundle : engine -> string -> unit =
  "cadmiumswixml_set_resource_bundle"


(* Rendering *)

external render_from_file : engine -> string -> Cadmium.java_object =
  "cadmiumswixml_render_from_file"

external render_from_url : engine -> string -> Cadmium.java_object =
  "cadmiumswixml_render_from_url"

external render_from_resource : engine -> string -> Cadmium.java_object =
  "cadmiumswixml_render_from_resource"

external render_from_channel : engine -> in_channel -> Cadmium.java_object =
  "cadmiumswixml_render_from_channel"


(* Insertion *)

external insert_from_url : engine -> string -> Cadmium.java_object -> unit =
  "cadmiumswixml_insert_from_url"

external insert_from_resource : engine -> string -> Cadmium.java_object -> unit =
  "cadmiumswixml_insert_from_resource"

external insert_from_channel : engine -> in_channel -> Cadmium.java_object -> unit =
  "cadmiumswixml_insert_from_channel"


(* Access to components *)

external get_root_component : engine -> Cadmium.java_object =
  "cadmiumswixml_get_root_component"

external get_id_map : engine -> (string * Cadmium.java_object) list =
  "cadmiumswixml_get_id_map"

external clear_id_map : engine -> unit =
  "cadmiumswixml_clear_id_map"

external get_all_components : engine -> Cadmium.java_object list =
  "cadmiumswixml_get_all_components"

external get_descendants : engine -> Cadmium.java_object -> Cadmium.java_object list =
  "cadmiumswixml_get_descendants"

external find : engine -> string -> Cadmium.java_object =
  "cadmiumswixml_find"

external forget : engine -> string -> unit =
  "cadmiumswixml_forget"

external cleanup : engine -> int =
  "cadmiumswixml_cleanup"

external set_action_listener : engine -> Cadmium.java_object -> Cadmium.java_object -> bool =
  "cadmiumswixml_set_action_listener"

let set_action_listener_by_name e n l =
  let cmp = find e n in
  set_action_listener e cmp l


(* Miscellaneous *)

let java_object_of_engine x = x
